<?php
/**
 * The template for displaying video post
 *
 * @package WordPress
 * @subpackage Louvre
 * @since Louvre 1.0
 */

global $airkit_is_ajax_loading;

$airkit_video 			= '';
$button					= false;
$article_classes 		= array('ts-single-video');
$section_classes 		= array();
$figure_attributes 		= array();

$airkit_sidebar 		= airkit_Compilator::build_sidebar( $post->ID );
$airkit_content_width 	= airkit_Compilator::get_content_width( $airkit_sidebar['content_class'] );
$airkit_sidebar_position = airkit_has_sidebar( $post->ID );
$airkit_is_img 			= airkit_single_option( 'img' );
$airkit_img_src 		= wp_get_attachment_url( get_post_thumbnail_id( $post->ID ) );
$lazyload_enabled 		= airkit_option_value( 'general', 'enable_imagesloaded' );

$article_classes[] 		= $airkit_content_width;
$section_classes[] 		= 'sidebar-'.$airkit_sidebar_position;
$section_classes[] 		= $airkit_sidebar['content_class'];

$airkit_video_type 		= get_post_meta( $post->ID, 'video_type', true );
$airkit_external_video 	= get_post_meta( $post->ID, 'video_external', true );
$airkit_embedded_video 	= get_post_meta( $post->ID, 'video_embedded', true );
$airkit_uploaded_video 	= get_post_meta( $post->ID, 'video_uploaded', true );


if( 'external' === $airkit_video_type && !empty( $airkit_external_video ) ){
	$button = true;
} elseif( 'embedded' === $airkit_video_type && !empty( $airkit_embedded_video ) ){
	$button = true;
} elseif ( 'uploaded' === $airkit_video_type && !empty( $airkit_uploaded_video ) ) {
	$button = true;
}

/*
 * Get categories ['list', 'slugs', 'ids' ]
 */
$airkit_categories = airkit_PostMeta::categories( $post->ID, array( 'get-array' => 'y', 'single' => 'y' ) );	

// Add class if post has sidebar set
if ( $airkit_sidebar_position != 'none' ) {
	$article_classes[] = 'has-post-sidebar ';
}

$figure_attributes['class'][] = 'featured-image';

if ( 'y' == $lazyload_enabled ) {
	$figure_attributes['class'][] = 'lazy';
	$figure_attributes['data-original'] = esc_url( $airkit_img_src );
}

if ( !empty($airkit_img_src) && 'n' == $lazyload_enabled ) {
	$figure_attributes['style'] = 'background-image: url('. esc_url( $airkit_img_src ) .');';
}


if ( 'y' == airkit_option_value( 'single', 'article_progress' ) ) {
	$article_classes[] = 'article-progress-enabled';
}

$article_atts['class'] = get_post_class( $article_classes );
?>

<div <?php airkit_element_attributes( array(), array('element' => 'post-row'), $post->ID ); ?>>

	<div class="container-fluid">
		<?php
			if ( 'y' == airkit_single_option( 'breadcrumbs' ) ) {

				echo '<div class="col-lg-12"><div class="airkit_breadcrumbs breadcrumbs-single-post container">' . airkit_breadcrumbs() . '</div></div>';

			}
		?>

		<?php
			if ( isset($airkit_is_ajax_loading) && true === $airkit_is_ajax_loading ) {
				if( airkit_option_value('advertising', 'ad_area_next_loaded') != '' ) {
					echo '<div class="text-center airkit_advertising-container container">' . airkit_option_value('advertising', 'ad_area_next_loaded') . '</div>';
				}
			}
		?>

		<article <?php airkit_element_attributes( $article_atts, array('element' => 'article', 'is-single' => true), $post->ID ) ?>>

			<?php airkit_progress_scroll(); ?>
			
			<?php
				if( !post_password_required() ) {

					if ( 'y' === $airkit_is_img && has_post_thumbnail( $post->ID ) ) {

						echo '<figure '. airkit_element_attributes( $figure_attributes, array(), $post->ID, false ) .'>';

							echo '<div class="video-figure-content content-w-800">';

								if ( 'y' === airkit_option_value( 'general', 'enable_lightbox' ) && !$button ) {
									echo '<a href="' . esc_url( $airkit_img_src ) . '" data-fancybox="' . $post->ID . '">';
								}

								echo get_the_post_thumbnail( $post->ID, 'louvre_wide');
								airkit_overlay_effect_type();

								if ( 'y' === airkit_option_value( 'general', 'enable_lightbox' ) && !$button ) {
									echo '</a>';
								}

								if ( $button ) {
									echo '<button type="button" data-post-id="'. esc_attr($post->ID) .'" data-ajax-nonce="'. wp_create_nonce( 'ajax_airkit_insert_video_content' ) .'" class="airkit_video-open"><i class="icon-play"></i><span>'. esc_html__('Play', 'louvre') .'</span></button><div class="embedded_videos"><div data-frame-id="'. $post->ID .'" class="video-frame" itemprop="video"></div></div>';
								}

							echo '</div>';

						echo '</figure>';
					}

				}
			?>

			<header class="text-center post-header">
				<?php
					echo airkit_PostMeta::post_format( $post->ID );
					echo airkit_PostMeta::categories( $post->ID, array( 'wrap-class' => 'post-categories entry-categories' ) );
					echo airkit_PostMeta::title( $post->ID, array( 'wrap' => 'h2', 'class' => 'entry-title post-title', 'url' => 'n', 'single' => 'y' ) );
				?>
			</header>

			<aside class="text-center post-meta">
				<?php
					echo airkit_PostMeta::author( $post->ID, array('wrap' => 'div', 'prefix' => '<em>' . esc_html__('by', 'louvre') . '</em>' ) );
					echo airkit_PostMeta::single_meta( $post->ID, array(), array('author', 'comments') );
					echo airkit_PostMeta::microdata();
					airkit_single_sharing( array('label' => 'y', 'tooltip-popover' => 'n', 'style' => 'button-sharing') );
				?>
			</aside>

			<aside class="post-container container">
				<?php
					if ( $airkit_sidebar_position !== 'none' ) {
						echo '<div class="row">'. airkit_var_sanitize( $airkit_sidebar['left'], 'true' ) .'<div class="'. implode(' ', $section_classes) .'">';
					}
				?>
				
				<div class="post-content">
					<?php
						echo airkit_PostMeta::subtitle( $post->ID, array( 'single' => 'y' ) );

						do_action( 'airkit_above_single_content' );

						the_content();

						do_action( 'airkit_below_single_content' );
					?>
				</div>
				<div class="post-footer">
				<?php 
					echo airkit_PostMeta::rating_single( $post->ID );

					if( !isset( $airkit_is_ajax_loading ) || false == $airkit_is_ajax_loading ) {
						airkit_PostMeta::single_pagination( $post->ID );
					}

					airkit_PostMeta::author_box( $post );

					//comments and relates posts should not be displayed when ajax loading
					if( !isset( $airkit_is_ajax_loading ) || false == $airkit_is_ajax_loading ) {

						comments_template( '', true );
						
						do_action( 'airkit_related_posts' );
						
					}
				?>
				</div>
				<?php
					if ( $airkit_sidebar_position !== 'none' ) {
						echo '</div>'. airkit_var_sanitize( $airkit_sidebar['right'], 'true' ) .'</div><!-- end .row -->';
					}
				?>
			</aside>

		</article>
		
	</div>
</div>
