<?php

class airkit_BuilderSettings
{
    static $repeat_set = array();

    static function get_icons()
    {
        $icons = get_option( 'louvre_icons', array() );

        if ( empty( $icons ) ) {

            return array();
        }

        return explode( ',', $icons );
    }

    static function get_setting( $pull )
    {
        if ( empty( self::$repeat_set ) ) {

            self::$repeat_set = array(

                'target' => array(
                    'name'    => esc_html__( 'Link target', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        '_self'  => esc_html__( 'Open is same tab', 'louvre' ),
                        '_blank' => esc_html__( 'Open link in new tab', 'louvre' )
                    ),
                    'id'       => 'target',
                    'std'      => '_blank'
                ),

                'icon' => array(
                    'name'    => esc_html__( 'Choose an icon', 'louvre' ),
                    'field'   => 'list_select',
                    'options' => self::get_icons(),
                    'id'      => 'icon',
                    'std'     => 'icon-noicon'
                ),

                'icon-color' => array(
                    'name'  => esc_html__( 'Choose an icon color', 'louvre' ),
                    'field' => 'input_color',
                    'id'    => 'font-color',
                    'std'   => '#777'
                ),

                'carousel' => array(
                    'name'    => esc_html__( 'Enable carousel', 'louvre' ),
                    'desc'    => esc_html__( 'If enabled, it will create a sliding carousel', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'y' => esc_html__( 'Yes', 'louvre' ),
                        'n' => esc_html__( 'No', 'louvre' )
                    ),
                    'id'       => 'carousel',
                    'std'      => 'n',
                    'class_select' => 'airkit_trigger-options',
                ),

                'bg-video-mp' => array(
                    'name'       => esc_html__( 'Upload a video MP4 format for background', 'louvre' ),
                    'desc'       => esc_html__( 'Add a background video. We strongly recommend to use muted videos, since there is no way to stop, pause or mute a background video.', 'louvre' ),
                    'field'      => 'upload',
                    'media-type' => 'video',
                    'multiple'   => 'false',
                    'id'         => 'bg-video-mp',
                    'std'        => ''
                ),

                'bg-video-webm' => array(
                    'name'       => esc_html__( 'Upload a video WebM format for background', 'louvre' ),
                    'desc'       => esc_html__( 'Add a background video. We strongly recommend to use muted videos, since there is no way to stop, pause or mute a background video.', 'louvre' ),
                    'field'      => 'upload',
                    'multiple'   => 'false',
                    'media-type' => 'video',
                    'id'         => 'bg-video-webm',
                    'std'        => ''
                ),

                'margin-top' => array(
                    'name'  => esc_html__( 'Margin top', 'louvre' ),
                    'desc'  => esc_html__( 'This will add spacing above the element, outside it.', 'louvre' ),
                    'field' => 'input',
                    'type'  => 'number',
                    'id'    => 'margin-top',
                    'std'   => 0
                ),

                'margin-bottom' => array(
                    'name'  => esc_html__( 'Margin bottom', 'louvre' ),
                    'desc'  => esc_html__( 'This will add spacing below the element, outside it.', 'louvre' ),
                    'field' => 'input',
                    'type'  => 'number',
                    'id'    => 'margin-bottom',
                    'std'   => 0
                ),

                'padding-top' => array(
                    'name'  => esc_html__( 'Padding top', 'louvre' ),
                    'desc'  => esc_html__( 'This will add spacing in the top part of the element, inside it, so that the number of pixes you specify here is left as spacing.', 'louvre' ),
                    'field' => 'input',
                    'type'  => 'number',
                    'id'    => 'padding-top',
                    'std'   => 0
                ),

                'padding-right' => array(
                    'name'  => esc_html__( 'Padding right', 'louvre' ),
                    'desc'  => esc_html__( 'This will add spacing on right side of the element, inside it, so that the number of pixes you specify here is left as spacing.', 'louvre' ),
                    'field' => 'input',
                    'type'  => 'number',
                    'id'    => 'padding-right',
                    'std'   => 0
                ),

                'padding-bottom' => array(
                    'name'  => esc_html__( 'Padding bottom', 'louvre' ),
                    'desc'  => esc_html__( 'This will add spacing in the bottom part of the element, inside it, so that the number of pixes you specify here is left as spacing.', 'louvre' ),
                    'field' => 'input',
                    'type'  => 'number',
                    'id'    => 'padding-bottom',
                    'std'   => 0
                ),

                'padding-left' => array(
                    'name'  => esc_html__( 'Padding left', 'louvre' ),
                    'desc'  => esc_html__( 'This will add spacing on left side of the element, inside it, so that the number of pixes you specify here is left as spacing.', 'louvre' ),
                    'field' => 'input',
                    'type'  => 'number',
                    'id'    => 'padding-left',
                    'std'   => 0
                ),

                'border-top' => array(
                    'name'    => esc_html__( 'Border top', 'louvre' ),
                    'desc'    => esc_html__( 'If enabled, it will add a border at the top is the element with the options you select below', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'y' => esc_html__( 'Yes', 'louvre' ),
                        'n' => esc_html__( 'No', 'louvre' )
                    ),
                    'id'           => 'border-top',
                    'std'          => 'n',
                    'class_select' => 'airkit_trigger-options'
                ),

                'border-top-width' => array(
                    'name'  => esc_html__( 'Border top width', 'louvre' ),
                    'desc'  => esc_html__( 'Select the width (size) of the border top. You can set anything from 1 to 15.', 'louvre' ),
                    'field' => 'slider_drag',
                    'min'   => 1,
                    'max'   => 15,
                    'step'  => 1,
                    'id'    => 'border-top-width',
                    'std'   => 1,
                    'class' => 'airkit_border-top-y'
                ),

                'border-top-color' => array(
                    'name'  => esc_html__( 'Border top color', 'louvre' ),
                    'desc'  => esc_html__( 'Select a color you want your border top to be.', 'louvre' ),
                    'field' => 'input_color',
                    'id'    => 'border-top-color',
                    'std'   => '#DDDDDD',
                    'class' => 'airkit_border-top-y'
                ),

                'border-right' => array(
                    'name'    => esc_html__( 'Border right', 'louvre' ),
                    'desc'    => esc_html__( 'If enabled, it will add a border at the right side of the element with the options you select below', 'louvre' ),
                    'field'   => 'select',
                    'field'   => 'select',
                    'options' => array(
                        'y' => esc_html__( 'Yes', 'louvre' ),
                        'n' => esc_html__( 'No', 'louvre' )
                    ),
                    'id'           => 'border-right',
                    'std'          => 'n',
                    'class_select' => 'airkit_trigger-options'
                ),

                'border-right-width' => array(
                    'name'  => esc_html__( 'Border right width', 'louvre' ),
                    'desc'  => esc_html__( 'Select the width (size) of the border right. You can set anything from 1 to 15.', 'louvre' ),
                    'field' => 'slider_drag',
                    'min'   => 1,
                    'max'   => 15,
                    'step'  => 1,
                    'id'    => 'border-right-width',
                    'std'   => 1,
                    'class' => 'airkit_border-right-y'
                ),

                'border-right-color' => array(
                    'name'  => esc_html__( 'Border right color', 'louvre' ),
                    'desc'  => esc_html__( 'Select a color you want your border top to be.', 'louvre' ),
                    'field' => 'input_color',
                    'id'    => 'border-right-color',
                    'std'   => '#DDDDDD',
                    'class' => 'airkit_border-right-y'
                ),

                'border-bottom' => array(
                    'name'    => esc_html__( 'Border bottom', 'louvre' ),
                    'desc'    => esc_html__( 'If enabled, it will add a border at the bottom of the element with the options you select below', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'y' => esc_html__( 'Yes', 'louvre' ),
                        'n' => esc_html__( 'No', 'louvre' )
                    ),
                    'id'           => 'border-bottom',
                    'std'          => 'n',
                    'class_select' => 'airkit_trigger-options'
                ),

                'border-bottom-width' => array(
                    'name'  => esc_html__( 'Border bottom width', 'louvre' ),
                    'desc'  => esc_html__( 'Select the width (size) of the border bottom. You can set anything from 1 to 15.', 'louvre' ),
                    'field' => 'slider_drag',
                    'min'   => 1,
                    'max'   => 15,
                    'step'  => 1,
                    'id'    => 'border-bottom-width',
                    'std'   => 1,
                    'class' => 'airkit_border-bottom-y'
                ),

                'border-bottom-color' => array(
                    'name'  => esc_html__( 'Border bottom color', 'louvre' ),
                    'desc'  => esc_html__( 'Select a color you want your border top to be.', 'louvre' ),
                    'field' => 'input_color',
                    'id'    => 'border-bottom-color',
                    'std'   => '#DDDDDD',
                    'class' => 'airkit_border-bottom-y'
                ),

                'border-left' => array(
                    'name'    => esc_html__( 'Border left', 'louvre' ),
                    'desc'    => esc_html__( 'If enabled, it will add a border at the right side of the element with the options you select below', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'y' => esc_html__( 'Yes', 'louvre' ),
                        'n' => esc_html__( 'No', 'louvre' )
                    ),
                    'id'           => 'border-left',
                    'std'          => 'n',
                    'class_select' => 'airkit_trigger-options'
                ),

                'border-left-width' => array(
                    'name'  => esc_html__( 'Border left width', 'louvre' ),
                    'desc'  => esc_html__( 'Select the width (size) of the border left. You can set anything from 1 to 15.', 'louvre' ),
                    'field' => 'slider_drag',
                    'min'   => 1,
                    'max'   => 15,
                    'step'  => 1,
                    'id'    => 'border-left-width',
                    'std'   => 1,
                    'class' => 'airkit_border-left-y'
                ),

                'border-left-color' => array(
                    'name'  => esc_html__( 'Border left color', 'louvre' ),
                    'desc'  => esc_html__( 'Select a color you want your border top to be.', 'louvre' ),
                    'field' => 'input_color',
                    'id'    => 'border-left-color',
                    'std'   => '#DDDDDD',
                    'class' => 'airkit_border-left-y'
                ),

                'text-color' => array(
                    'name'  => esc_html__( 'Text color', 'louvre' ),
                    'desc'  => esc_html__( 'Choose a text color for the content of this element. Note that not all colors inside will be changed, as most come from theme options and other element settings. This affects mostly texts.', 'louvre' ),
                    'field' => 'input_color',
                    'id'    => 'text-color',
                    'std'   => '#000000'
                ),

                'bg-color' => array(
                    'name'  => esc_html__( 'Choose background color', 'louvre' ),
                    'desc'  => esc_html__( 'Add a background color to this element. Note that this will only affect this element.', 'louvre' ),
                    'field' => 'input_color',
                    'id'    => 'bg-color',
                    'std'   => '#ffffff'
                ),

                'text-align' => array(
                    'name'    => esc_html__( 'Text align', 'louvre' ),
                    'desc'    => esc_html__( 'You can select the align of the text inside this column. Keep in mind that some element aligns are hardcoded and you cannot change them.', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'left'   => esc_html__( 'Left', 'louvre' ),
                        'center' => esc_html__( 'Center', 'louvre' ),
                        'right'  => esc_html__( 'Right', 'louvre' ),
                    ),
                    'id'      => 'text-align',
                    'std'     => 'left'
                ),

                'parallax' => array(
                    'name'    => esc_html__( 'Enable image parallax', 'louvre' ),
                    'desc'    => esc_html__( 'If you have a background image set, this will add subtle parallax efect for the background image of this specifc row.', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'y' => esc_html__( 'Yes', 'louvre' ),
                        'n' => esc_html__( 'No', 'louvre' )
                    ),
                    'id'       => 'parallax',
                    'std'      => 'n'
                ),

                'bg-img' => array(
                    'name'       => esc_html__( 'Upload background image', 'louvre' ),
                    'desc'       => esc_html__( 'If you want to add a background image to this element, please upload it or select one from the media library.', 'louvre' ),
                    'field'      => 'upload',
                    'media-type' => 'image',
                    'multiple'   => 'false',
                    'id'         => 'bg-img',
                    'std'        => ''
                ),

                'bg-x' => array(
                    'name'    => esc_html__( 'Background position X axis', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'left'   => esc_html__( 'Left', 'louvre' ),
                        'center' => esc_html__( 'Center', 'louvre' ),
                        'right'  => esc_html__( 'Right', 'louvre' ),
                    ),
                    'id'       => 'bg-x',
                    'std'      => 'left'
                ),

                'bg-y' => array(
                    'name'    => esc_html__( 'Background position Y axis', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'top'    => esc_html__( 'Top', 'louvre' ),
                        'center' => esc_html__( 'Center', 'louvre' ),
                        'bottom' => esc_html__( 'Bottom', 'louvre' ),
                    ),
                    'id'       => 'bg-y',
                    'std'      => 'top'
                ),

                'bg-attachement' => array(
                    'name'    => esc_html__( 'Background attachment', 'louvre' ),
                    'desc'    => esc_html__( 'Choose your background attachment style. You can make it static or scroll align with the website. For more info, please search the web about the background attachment option.', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'fixed'  => esc_html__( 'Fixed', 'louvre' ),
                        'scroll' => esc_html__( 'Scroll', 'louvre' )
                    ),
                    'id'       => 'bg-attachement',
                    'std'      => 'fixed'
                ),

                'bg-repeat' => array(
                    'name'    => esc_html__( 'Background repeat', 'louvre' ),
                    'desc'    => esc_html__( 'You can choose to repeat the background for this specific element.', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'repeat'    => esc_html__( 'Repeat', 'louvre' ),
                        'no-repeat' => esc_html__( 'No repeat', 'louvre' ),
                        'repeat-x'  => esc_html__( 'Horizontaly', 'louvre' ),
                        'repeat-y'  => esc_html__( 'Verticaly', 'louvre' )
                    ),
                    'id'       => 'bg-repeat',
                    'std'      => 'no-repeat'
                ),

                'bg-size' => array(
                    'name'    => esc_html__( 'Background size', 'louvre' ),
                    'desc'    => esc_html__( 'If you are using a background image, select the background size that you want. You can have it auto so it will keep the image size that you have uploaded or set it cover, so it makes sure that image will fill the row vertically and horizontally. Keep in mind that the second option could crop bits of your image and will not always show 100% the part of the image you want. You can also set it to contain, so the image will be scaled to the container size such that both its width and its height can fit inside the content area', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'auto'  => esc_html__( 'Auto', 'louvre' ),
                        'cover' => esc_html__( 'Cover', 'louvre' ),
                        'contain' => esc_html__( 'Contain', 'louvre' ),
                    ),
                    'id'  => 'bg-size',
                    'std' => 'no-repeat'
                ),

                'mask' => array(
                    'name'    => esc_html__( 'Enable background mask', 'louvre' ),
                    'desc'    => esc_html__( 'If enabled, this will add a subtle overlay effect to the background settings. It is recommended to be used with background image.', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'y'        => esc_html__( 'Color', 'louvre' ),
                        'n'        => esc_html__( 'No mask', 'louvre' ),
                        'gradient' => esc_html__( 'Gradient', 'louvre' )
                    ),
                    'id'           => 'mask',
                    'std'          => 'n',
                    'class_select' => 'airkit_trigger-options'
                ),

                'mask-color' => array(
                    'name'  => esc_html__( 'Background mask color #1', 'louvre' ),
                    'desc'  => esc_html__( 'If you use a single tone mask style, you can select the color of it here.', 'louvre' ),
                    'field' => 'input_color',
                    'id'    => 'mask-color',
                    'std'   => '#DDDDDD',
                    'class' => 'airkit_mask-y airkit_mask-gradient'
                ),

                'mask-gradient-color' => array(
                    'name'  => esc_html__( 'Background mask color #2', 'louvre' ),
                    'desc'  => esc_html__( 'If you use a gradient tone mask style, you can select the secondary color of it here.', 'louvre' ),
                    'field' => 'input_color',
                    'id'    => 'mask-gradient-color',
                    'std'   => '#DDDDDD',
                    'class' => 'airkit_mask-gradient'
                ),

                'gradient-type' => array(
                    'name'    => esc_html__( 'Background mask gradient style', 'louvre' ),
                    'desc'    => esc_html__( 'If you selected the gradient style for the background mask, you can choose the style of it here from the available options', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'radial'        => esc_html__( 'Radial (from center to corners)', 'louvre' ),
                        'top-to-bottom' => esc_html__( 'From top to bottom', 'louvre' ),
                        'left-to-right' => esc_html__( 'From left to right', 'louvre' ),
                        'corner-top'    => esc_html__( 'From top left corner to bottom right corner', 'louvre' ),
                        'corner-bottom' => esc_html__( 'From bottom left corner to top right corner', 'louvre' )
                    ),
                    'id'       => 'gradient-type',
                    'std'      => 'radial',
                    'class'    => 'airkit_mask-gradient'
                ),

                'per-row' => array(
                    'name'    => esc_html__( 'Number of elements per row', 'louvre' ),
                    'desc'    => esc_html__( 'Choose the number of elements you want to use per line. For example, if you want a grid of 3 items choose the 3 columns layout', 'louvre' ),
                    'field'   => 'img_selector',
                    'options' => array(
                        1 => 1,
                        2 => 2,
                        3 => 3,
                        4 => 4,
                        6 => 6
                    ),
                    'img' => array(
                        1 => 'per_row_1.png',
                        2 => 'per_row_2.png',
                        3 => 'per_row_3.png',
                        4 => 'per_row_4.png',
                        6 => 'per_row_6.png',
                    ),
                    'id'       => 'per-row',
                    'std'      => 2
                ),

                'pagination' => array(
                    'name'    => esc_html__( 'Enable pagination', 'louvre' ),
                    'desc'    => esc_html__( 'Choose a pagination style for your content. You can select from none which will show only the number of posts you want to extract or use number pagination, load more button or infinite scrolling. When you activate a style of pagination, it will show the next number of posts as the default number you selected', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'none'      => esc_html__( 'None', 'louvre' ),
                        'numeric'   => esc_html__( 'Number pagination', 'louvre' ),
                        'load-more' => esc_html__( 'Load more button', 'louvre' ),
                        'infinite'  => esc_html__( 'Infinite scrolling', 'louvre' )
                    ),
                    'id'    => 'pagination',
                    'std'   => 'none',
                    'class' => 'airkit_behavior-normal airkit_behavior-masonry airkit_scroll-n airkit_small-posts-n',
                    'class_select' => 'airkit_trigger-options',
                ),

                'styling' => array(
                    'name'    => esc_html__( 'View background/border styling', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'none'     => esc_html__( 'None', 'louvre' ),
                        'border'   => esc_html__( 'Border', 'louvre' ),
                        'bg-color' => esc_html__( 'Background color', 'louvre' )
                    ),
                    'id'           => 'styling',
                    'std'          => 'none',
                    'class_select' => 'airkit_trigger-options'
                ),

                'bg-color' => array(
                    'name'  => esc_html__( 'Choose background color', 'louvre' ),
                    'field' => 'input_color',
                    'id'    => 'bg-color',
                    'std'   => '#ffffff',
                    'class' => 'airkit_styling-bg-color'
                ),

                'border-color' =>  array(
                    'name'  => esc_html__( 'Choose border color', 'louvre' ),
                    'field' => 'input_color',
                    'id'    => 'border-color',
                    'std'   => '#DDDDDD',
                    'class' => 'airkit_styling-border'
                ),

                'gutter-space' => array(
                    'name'    => esc_html__( 'Gutter space', 'louvre' ),
                    'desc'    => esc_html__( 'Gutter space means the space between the elements (columns) that are used. Depending on the white spacing you want for your website, choose a style that fits you best', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'n' => esc_html__( 'None', 'louvre' ),
                        '10'  => '10',
                        '20'  => '20',
                        '30'  => '30',
                        '40'  => '40',
                        '50'  => '50',
                        '60'  => '60'
                    ),
                    'id'      => 'gutter-space',
                    'std'     => '40'
                ),

                'small-posts' => array(
                    'name'    => esc_html__( 'Enable small posts', 'louvre' ),
                    'desc'    => esc_html__( 'If this option is enabled, only the first article will have the default post view you selected. The rest will be shown below as small articles. This is used best for categories or post lists you want to create.', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'y' => esc_html__( 'Yes', 'louvre' ),
                        'n' => esc_html__( 'No', 'louvre' )
                    ),
                    'id'    => 'small-posts',
                    'std'   => 'n',
                    'class' => 'airkit_pagination-none'
                ),

                'excerpt' => array(
                    'name'    => esc_html__( 'Show post excerpt', 'louvre' ),
                    'desc'    => esc_html__( 'You can remove the preview text used in views if you don\'t need it or if you do not like it', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'y' => esc_html__( 'Yes', 'louvre' ),
                        'n' => esc_html__( 'No', 'louvre' )
                    ),
                    'id'      => 'excerpt',
                    'std'     => 'y'
                ),

                'meta' => array(
                    'name'    => esc_html__( 'Show post meta', 'louvre' ),
                    'desc'    => esc_html__( 'You can choose to show or to hide your meta details for your articles. Meta values include date, author, categories, tags and other article details.', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'y' => esc_html__( 'Yes', 'louvre' ),
                        'n' => esc_html__( 'No', 'louvre' )
                    ),
                    'id'       => 'meta',
                    'std'      => 'y'
                ),

                'posts-limit' => array(
                    'name'  => esc_html__( 'Posts to extract', 'louvre' ),
                    'desc'  => esc_html__( 'This is the number of posts that will be extracted from the database and shown in total. If you use pagination, this will be the default posts number and on each new iteration this number of posts will be extracted again.', 'louvre' ),
                    'field' => 'input',
                    'type'  => 'number',
                    'id'    => 'posts-limit',
                    'std'   => 4
                ),

                'featured' => array(
                    'name'    => esc_html__( 'Show only featured', 'louvre' ),
                    'desc'    => esc_html__( 'The theme has a featured option available, letting you choose your featured or preferred posts. You can find that option when you check the posts list in the WordPress Dashboard.', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'y' => esc_html__( 'Yes', 'louvre' ),
                        'n' => esc_html__( 'No', 'louvre' )
                    ),
                    'id'       => 'featured',
                    'std'      => 'n'
                ),

                'rated' => array(
                    'name'    => esc_html__( 'Show only rated posts', 'louvre' ),
                    'desc'    => esc_html__( 'If this option is enabled, only posts that have rating enabled will be extracted.', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'y' => esc_html__( 'Yes', 'louvre' ),
                        'n' => esc_html__( 'No', 'louvre' )
                    ),
                    'id'       => 'rated',
                    'std'      => 'n'
                ),

                'post__not_in' => array(
                    'name'  => esc_html__( 'Exclude post IDs', 'louvre' ),
                    'desc'  => esc_html__( 'If you want to exclude some posts IDs from the query, insert the ID here, separated by commas. Eg: 1,2,3,4', 'louvre' ),
                    'field' => 'input',
                    'type'  => 'text',
                    'id'    => 'post__not_in',
                    'std'   => ''
                ),

                'offset' => array(
                    'name'  => esc_html__( 'Exclude first posts from query', 'louvre' ),
                    'desc'  => esc_html__( 'If you want to disable the first number of posts from a query, enter the number you want to be excluded. For example, if you have 3 articles shown above in another element and you have the same query below, but you don\'t want to have duplicates - just set this option to 3, and the first 3 will be excluded from the list', 'louvre' ),
                    'field' => 'input',
                    'type'  => 'number',
                    'id'    => 'offset',
                    'std'   => 0
                ),

                'orderby' => array(
                    'name'    => esc_html__( 'Order posts by', 'louvre' ),
                    'desc'    => esc_html__( 'Choose your order criteria. You can sort your articles by date, number or comments, views or likes', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'date'     => esc_html__( 'Date', 'louvre' ),
                        'comments' => esc_html__( 'Comments', 'louvre' ),
                        'views'    => esc_html__( 'Views', 'louvre' ),
                        'likes'    => esc_html__( 'Likes', 'louvre' ),
                    ),
                    'id'       => 'orderby',
                    'std'      => 'date'
                ),

                'order' => array(
                    'name'    => esc_html__( 'Order direction', 'louvre' ),
                    'desc'    => esc_html__( 'Choose your order direction. You can sort your articles in an ascending or a descending way depending of the order by option above', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'ASC'  => esc_html__( 'Ascending', 'louvre' ),
                        'DESC' => esc_html__( 'Descending', 'louvre' )
                    ),
                    'id'       => 'order',
                    'std'      => 'DESC'
                ),

                'post-type' => array(
                    'name'    => esc_html__( 'Choose your posts type', 'louvre' ),
                    'desc'    => esc_html__( 'Here you can choose the post type you want to showcase here. Note that you can\'t have different posts types in the same query, so only one will be shown.', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'post'       => esc_html__( 'Posts', 'louvre' ),
                        'video'      => esc_html__( 'Videos', 'louvre' ),
                        'ts-gallery' => esc_html__( 'Galleries', 'louvre' ),
                        'portfolio'  => esc_html__( 'Portfolio', 'louvre' ),
                    ),
                    'id'           => 'post-type',
                    'std'          => 'post',
                    'class_select' => 'airkit_trigger-options'
                ),

                'post-format' => array(
                    'name'    => esc_html__( 'Choose your posts format', 'louvre' ),
                    'desc'    => esc_html__( 'Here you can choose the post format of the posts you want to showcase here. ', 'louvre' ),
                    'field'   => 'select',
                    'options' => array(
                        'all'                   => esc_html__( 'All post formats', 'louvre' ),
                        'post-format-standard'  => esc_html__( 'Standard post format', 'louvre' ),
                        'post-format-video'     => esc_html__( 'Video post format', 'louvre' ),
                        'post-format-gallery'   => esc_html__( 'Gallery post format', 'louvre' ),
                        'post-format-audio'     => esc_html__( 'Audio post format', 'louvre' ),
                    ),
                    'id'           => 'post-format',
                    'std'          => 'all',
                    // 'class_select' => 'airkit_post-type-post',
                    'class'        => 'airkit_post-type-post'
                ),

                'taxonomies' => array(
                    'name'          => esc_html__( 'Choose taxonomy', 'louvre' ),
                    'desc'          => esc_html__( 'Here you can choose one taxonomy from all public registered taxonomies on your website.', 'louvre' ),
                    'field'         => 'select',
                    'options'       => get_taxonomies( array( 'public' => true ) ),
                    'id'            => 'taxonomy',
                    'std'           => '',
                    'class_select'  => 'airkit_trigger-options'
                ),

                'category' => array(
                    'name'         => esc_html__( 'Choose your posts categories', 'louvre' ),
                    'desc'         => esc_html__( 'These are the post categories you added on your website and that have at least one post assigned to them. Choose the ones you want to showcase posts from.', 'louvre' ),
                    'field'        => 'select',
                    'options'      => wp_list_pluck( get_categories( array( 'hide_empty' => 1, 'show_option_all' => '' ) ), 'cat_name', 'slug' ),
                    'id'           => 'category',
                    'class_select' => 'ts-custom-select-input',
                    'multiple'     => true,
                    'std'          => '',
                    'class'        => 'airkit_post-type-post'
                ),

                'gallery_categories' => array(
                    'name'         => esc_html__( 'Choose your gallery categories', 'louvre' ),
                    'desc'         => esc_html__( 'These are the gallery categories you added on your website and that have at least one post assigned to them. Choose the ones you want to showcase posts from.', 'louvre' ),
                    'field'        => 'select',
                    'options'      => wp_list_pluck( get_categories( array( 'hide_empty' => 1, 'taxonomy' => 'gallery_categories' ) ), 'cat_name', 'slug' ),
                    'id'           => 'gallery_categories',
                    'class_select' => 'ts-custom-select-input',
                    'multiple'     => true,
                    'std'          => '',
                    'class'        => 'airkit_post-type-ts-gallery'
                ),

                'videos_categories' => array(
                    'name'         => esc_html__( 'Choose your video categories', 'louvre' ),
                    'desc'         => esc_html__( 'These are the posts categories you added on your website and that have at least one post assigned to them. Choose the ones you want to showcase posts from.', 'louvre' ),
                    'field'        => 'select',
                    'options'      => wp_list_pluck( get_categories( array( 'hide_empty' => 1, 'taxonomy' => 'videos_categories' ) ), 'cat_name', 'slug' ),
                    'id'           => 'videos_categories',
                    'class_select' => 'ts-custom-select-input',
                    'multiple'     => true,
                    'std'          => '',
                    'class'        => 'airkit_post-type-video'
                ),

                'portfolio_categories' => array(
                    'name'         => esc_html__( 'Choose your portfolio categories', 'louvre' ),
                    'desc'         => esc_html__( 'These are the portfolio categories you added on your website and that have at least one post assigned to them. Choose the ones you want to showcase posts from.', 'louvre' ),
                    'field'        => 'select',
                    'options'      => wp_list_pluck( get_categories( array( 'hide_empty' => 1, 'taxonomy' => 'portfolio-categories' ) ), 'cat_name', 'slug' ),
                    'id'           => 'portfolio-categories',
                    'class_select' => 'ts-custom-select-input',
                    'multiple'     => true,
                    'std'          => '',
                    'class'        => 'airkit_post-type-portfolio'
                ),

                'tags' => array(
                    'name'         => esc_html__( 'Narrow query by tags', 'louvre' ),
                    'desc'         => esc_html__( 'If you want to get posts that by a tag, write them down separated by commas.', 'louvre' ),
                    'field'        => 'input',
                    'type'         => 'text',
                    'id'           => 'tags',
                    'std'          => '',
                ),

                'reveal-effect' => array(
                    'name'         => esc_html__( 'Reveal effect', 'louvre' ),
                    'desc'         => esc_html__( 'If you want this element to appear on the website with an effect when the elements gets in the viewport (browser visible area), choose an effect from below', 'louvre' ),
                    'field'        => 'select',
                    'options'      => airkit_all_animations( 'effect' ),
                    'id'           => 'reveal-effect',
                    'std'          => 'none',
                    'class_select' => 'airkit_trigger-options'
                ),

                'reveal-delay' => array(
                    'name'    => esc_html__( 'Reveal effect delay', 'louvre' ),
                    'field'   => 'select',
                    'options' => airkit_all_animations( 'delay' ),
                    'id'      => 'reveal-delay',
                    'std'     => 'delay-500',
                    'class'   => 'airkit_reveal-effect-none airkit_revert-trigger'
                ),

                'behavior' =>  array(
                    'name'    => esc_html__( 'Articles behavior', 'louvre' ),

                    'desc'    => esc_html__( 'You can choose your articles to be shown with a specific behavior. Note that if you want a pagination, this option will not work properly and you have to disable one of them. You can set your posts to be shown in a carousel option, arrange them in a masonry (find the space) way, use a horizontal scroll option which adds a scroll bar at the bottom of the view or use category filters which will create a tabs effect', 'louvre' ),
                    'field'   => 'img_selector',

                    'options' => array(
                        'normal'   => 'normal',
                        'carousel' => 'carousel',
                        'masonry'  => 'masonry',
                        'scroll'   => 'scroll',
                        'filters'  => 'filters'

                    ),

                    'img' => array(
                        'normal'   => 'behavior_none.png',
                        'carousel' => 'behavior_carousel.png',
                        'masonry'  => 'behavior_masonry.png',
                        'scroll'   => 'behavior_scroll.png',
                        'filters'  => 'behavior_tabs.png'
                    ),

                    'id'           => 'behavior',
                    'std'          => 'normal',
                    'class_select' => 'airkit_trigger-options'
                ),

                'carousel-nav' => array(
                    'name' => esc_html__( 'Carousel navigation type', 'louvre'),
                    'field'   => 'select',
                    'options' => array(
                        'none'   => esc_html__( 'None', 'louvre' ),
                        'arrows' => esc_html__( 'Arrows', 'louvre' ),
                        'dots'   => esc_html__( 'Dots', 'louvre' ),
                        'dots-arrows' => esc_html__( 'Dots and Arrows', 'louvre' ),
                    ),
                    'id'       => 'carousel-nav',
                    'std'      => 'arrows',
                    'class'    => 'airkit_behavior-carousel airkit_carousel-y'
                ),

                'carousel-scroll' => array(
                    'name' => esc_html__( 'Slides to scroll', 'louvre'),
                    'field'   => 'select',
                    'options' => array(
                        'by-col' => esc_html__( 'Column By Column', 'louvre' ),
                        'by-row' => esc_html__( 'Full row', 'louvre' ),
                    ),
                    'id'       => 'carousel-scroll',
                    'std'      => 'by-col',
                    'class'    => 'airkit_behavior-carousel airkit_carousel-y'
                ),
                                                
                'carousel-autoplay' => array(
                    'name' => esc_html__( 'Enable carousel autoplay', 'louvre'),
                    'field'   => 'select',
                    'options' => array(
                        'y' => 'Yes',
                        'n' => 'No',
                    ),
                    'id'       => 'carousel-autoplay',
                    'std'      => 'n',
                    'class'    => 'airkit_behavior-carousel airkit_carousel-y'
                ),

                'enable-ads' => array(
                    'name' => esc_html__( 'Enable advertising', 'louvre'),
                    'field'   => 'select',
                    'options' => array(
                        'y' => esc_html__( 'Yes', 'louvre' ),
                        'n' => esc_html__( 'No', 'louvre' ),
                    ),
                    'id'       => 'enable-ads',
                    'std'      => 'n',
                    'class_select'    => 'airkit_trigger-options'                    
                ),

                'ads-step' => array(
                    'name'  => esc_html__( 'Advertising step', 'louvre'),
                    'desc'  => esc_html__( 'Show advertising instead of each this number post:', 'louvre' ),
                    'id'    => 'ads-step',
                    'field' => 'slider_drag',
                    'min'   => 2,
                    'max'   => 20,
                    'step'  => 1,
                    'std'   => 4,
                    'class' => 'airkit_enable-ads-y'                    
                ),
        
            );
        }

        return self::$repeat_set[ $pull ];
    }

    static function row()
    {

        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Row ID', 'louvre' ),
                        'desc'  => esc_html__( 'You can set a specific ID to this row. This can be used to style elements or to create anchor links.', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'name',
                        'std'   => ''
                    ),

                    array(
                        'name'    => esc_html__( 'Set columns to equal heights', 'louvre' ),
                        'desc'    => esc_html__( 'If enabled this option will find the biggest column (in height) and set all the other columns inside this row to have the same height.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'equal-height',
                        'std'      => 'n'
                    ),

                    array(
                        'name'    => esc_html__( 'Row content vertical align', 'louvre' ),
                        'desc'    => esc_html__( 'If your elements have different heights and you want to center them vertically inside this row, you can enable this option. Note that this is an experimental option, might conflict with some plugins/layouts', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'top'    => esc_html__( 'Top', 'louvre' ),
                            'middle' => esc_html__( 'Middle', 'louvre' ),
                            'bottom' => esc_html__( 'Bottom', 'louvre' ),
                        ),
                        'id'      => 'vertical-align',
                        'std'     => 'top'
                    ),

                    array(
                        'name'    => esc_html__( 'Make row sticky (fixed)', 'louvre' ),
                        'desc'    => esc_html__( 'If enabled, it will fix the row at the top of the browser window after you scroll below it. Very useful to create sticky headers with menus and logos inside it. Note that only one sticky row can be used per page.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'      => 'sticky',
                        'std'     => 'n',
                        'class_select' => 'airkit_trigger-options',
                    ),

                    array(
                        'name'    => esc_html__( 'Enable Smart Sticky behavior', 'louvre' ),
                        'desc'    => esc_html__( 'If enabled, row will have Smart Sticky behavior, which means hiding the element automatically when a user starts scrolling down the page and bringing it back when a user scrolls up.', 'louvre' ),                        
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'      => 'smart-sticky',
                        'std'     => 'n',
                        'class'   => 'airkit_sticky-y',
                    ),

                    array(
                        'name'    => esc_html__( 'Expand row content', 'louvre' ),
                        'desc'    => esc_html__( 'If enabled all the content inside will go from one edge of the screen to another. If you are using the boxed layout it will only extend to the box edges', 'louvre' ),
                        'field'   => 'img_selector',
                        'options' => array(
                            'n' => esc_html__( 'No', 'louvre' ),
                            'y' => esc_html__( 'Yes', 'louvre' ),                         
                        ),
                        'img' => array(
                            'n' => 'expand_row_no.png',
                            'y' => 'expand_row_yes.png',
                            
                        ),
                        'id'       => 'expand',
                        'std'      => 'n'
                    ),

                    array(
                        'name'    => esc_html__( 'Make row fullscreen', 'louvre' ),
                        'desc'    => esc_html__( 'If enabled, this will make this row to have the height of the browser window. Once you set it to fullscreen it will resize the row so that it fits the screen of the user. This will not expand your content horizontally though', 'louvre' ),
                        'field'   => 'img_selector',
                        'options' => array(
                            'n' => esc_html__( 'No', 'louvre' ),
                            'y' => esc_html__( 'Yes', 'louvre' ),
                        ),
                        'img' => array(
                            'n' => 'fullscreen_row_no.png',
                            'y' => 'fullscreen_row_yes.png',
                        ),
                        'id'  => 'fullscreen',
                        'std' => 'n'
                    ),

                    array(
                        'name'    => esc_html__( 'Add a box shadow', 'louvre' ),
                        'desc'    => esc_html__( 'If you enable this option, it will add a subtle box shadow inside the row edges', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'      => 'box-shadow',
                        'std'     => 'n'
                    ),

                    array(
                        'name'    => esc_html__( 'Convert row columns to carousel', 'louvre' ),
                        'desc'    => esc_html__( 'All columns you add will be converted to a full row and each column will represent a carousel item', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'      => 'carousel',
                        'std'     => 'n',
                        'class_select' => 'airkit_trigger-options',
                    ),

                    self::get_setting( 'carousel-nav' ),
                    self::get_setting( 'carousel-scroll' ),
                    self::get_setting( 'carousel-autoplay' ),                     


                    array(
                        'name'    => esc_html__( 'Add scroll down button', 'louvre' ),
                        'desc'    => esc_html__( 'This will add a small buttom at the bottom of the row that will show the users to scroll down and once clicked, it will scroll the browser window just below the row bottom edge', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'      => 'scroll-button',
                        'std'     => 'n'
                    ),

                    array(
                        'name'         => esc_html__( 'Reveal effect', 'louvre' ),
                        'desc'         => esc_html__( 'If you want this row to appear on the website with an effect when the elements gets in the viewport (browser visible area), choose an effect from below', 'louvre' ),
                        'field'        => 'select',
                        'options'      => airkit_all_animations( 'effect' ),
                        'id'           => 'reveal-effect',
                        'std'          => 'none',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    array(
                        'name'    => esc_html__( 'Reveal delay', 'louvre' ),
                        'field'   => 'select',
                        'options' => airkit_all_animations( 'delay' ),
                        'id'      => 'reveal-delay',
                        'std'     => 'delay-500',
                        'class'   => 'airkit_reveal-effect-none airkit_revert-trigger'
                    ),

                    array(
                        'name'  => esc_html__( 'Custom CSS', 'louvre' ),
                        'desc'  => esc_html__( 'The code you insert below will be added to the row\'s style attribute. You do not need to add any style tags, only the CSS attributes', 'louvre' ),
                        'field' => 'textarea',
                        'id'    => 'custom-css',
                        'std'   => ''
                    )
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    self::get_setting( 'text-align' ),


                    array(
                        'name'  => esc_html__( 'Choose row background color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'bg-color',
                        'std'   => 'rgba(255, 255, 255, 0)'
                    ),


                    self::get_setting( 'margin-top' ),
                    self::get_setting( 'margin-bottom' ),

                    self::get_setting( 'padding-top' ),
                    self::get_setting( 'padding-bottom' ),

                    self::get_setting( 'bg-video-mp' ),
                    self::get_setting( 'bg-video-webm' ),

                    self::get_setting( 'bg-img' ),
                    self::get_setting( 'bg-x' ),
                    self::get_setting( 'bg-y' ),
                    self::get_setting( 'bg-attachement' ),
                    self::get_setting( 'bg-repeat' ),
                    self::get_setting( 'bg-size' ),
                    self::get_setting( 'parallax' ),


                    array(
                          'name'    => esc_html__( 'Enable background slider', 'louvre' ),
                          'nadescme'    => esc_html__( 'If enabled it will let you create a slider with custom slides and captions that will be set as background for the elements you add in this row.', 'louvre' ),
                          'field' => 'select',
                          'options' => array(
                              'y' => esc_html__( 'Yes', 'louvre' ),
                              'n' => esc_html__( 'No', 'louvre' )
                          ),
                          'id'      => 'slider-bg',
                          'std'     => 'n',
                          'class_select'   => 'airkit_trigger-options'
                    ),

                    array(
                        'name' => esc_html__( 'Slider navigation type', 'louvre'),
                        'field'   => 'select',
                        'options' => array(
                            'none'   => esc_html__( 'None', 'louvre' ),
                            'arrows' => esc_html__( 'Arrows', 'louvre' ),
                            'dots'   => esc_html__( 'Dots', 'louvre' ),
                            'dots-arrows' => esc_html__( 'Dots and Arrows', 'louvre' ),
                        ),
                        'id'       => 'slider-nav',
                        'std'      => 'arrows',
                        'class'    => 'airkit_slider-bg-y'
                    ),
                          
                    array(
                        'name' => esc_html__( 'Enable Autoplay for slider', 'louvre'),
                        'field'   => 'select',
                        'options' => array(
                            'y' => 'Yes',
                            'n' => 'No',
                        ),
                        'id'       => 'slider-autoplay',
                        'std'      => 'n',
                        'class'    => 'airkit_slider-bg-y'
                    ),                 

                    array(
                        'name'     => esc_html__( 'Add new item', 'louvre' ),
                        'field'    => 'tmpl',
                        'id'       => 'items',
                        'sortable' => 'true',
                        'class'    => 'airkit_slider-bg-y',
                        'std'      => array(),
                        'options'  => array(

                            array(
                                'name'       => esc_html__( 'Slide image', 'louvre' ),
                                'field'      => 'upload',
                                'media-type' => 'image',
                                'multiple'   => 'false',
                                'id'         => 'image',
                                'std'        => '',
                            ),

                            array(
                                'name'  => esc_html__( 'Add title', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add your caption here', 'louvre' ),
                                'field' => 'textarea',
                                'id'    => 'text',
                                'std'   => ''
                            ),

                            self::get_setting( 'text-align' ),
                            self::get_setting( 'text-color' ),

                            array(
                                'name'  => esc_html__( 'Button 1 Text', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'button1',
                                'std'   => ''
                            ),
                            array(
                                'name'  => esc_html__( 'Button 1 redirect URL', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'url1',
                                'std'   => ''
                            ),
                            array(
                                'name'  => esc_html__( 'Button 2 Text', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'button2',
                                'std'   => ''
                            ),
                            array(
                                'name'  => esc_html__( 'Button 2 redirect URL', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'url2',
                                'std'   => ''
                            ),
                            array(
                                'name'  => esc_html__( 'Buttons border/background color', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'button-bg-color',
                                'std'   => 'rgba(255, 255, 255, 1)'
                            ),
                            array(
                                'name'  => esc_html__( 'Background button text color', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'button-text-color',
                                'std'   => 'rgba(0, 0, 0, 1)'
                            ),
                        )
                    ),

                    self::get_setting( 'mask' ),
                    self::get_setting( 'mask-color' ),
                    self::get_setting( 'mask-gradient-color' ),
                    self::get_setting( 'gradient-type' ),

                    self::get_setting( 'border-top' ),
                    self::get_setting( 'border-top-width' ),
                    self::get_setting( 'border-top-color' ),

                    self::get_setting( 'border-bottom' ),
                    self::get_setting( 'border-bottom-width' ),
                    self::get_setting( 'border-bottom-color' ),                 

                    self::get_setting( 'border-left' ),
                    self::get_setting( 'border-left-width' ),
                    self::get_setting( 'border-left-color' ),

                    self::get_setting( 'border-right' ),
                    self::get_setting( 'border-right-width' ),
                    self::get_setting( 'border-right-color' ),

                )
            )
        );
    }

    static function column()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Column ID', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'name',
                        'std'   => ''
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'size',
                        'std'   => 12,
                    ),

                    array(
                        'name'         => esc_html__( 'Reveal effect', 'louvre' ),
                        'field'        => 'select',
                        'options'      => airkit_all_animations( 'effect' ),
                        'id'           => 'reveal-effect',
                        'std'          => 'none',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    array(
                        'name'    => esc_html__( 'Reveal delay', 'louvre' ),
                        'field'   => 'select',
                        'options' => airkit_all_animations( 'delay' ),
                        'id'      => 'reveal-delay',
                        'std'     => 'delay-500',
                        'class'   => 'airkit_reveal-effect-none airkit_revert-trigger'
                    ),

                    array(
                        'name'  => esc_html__( 'Column width on tablet landscape', 'louvre' ),
                        'desc'  => esc_html__( 'You can set different column widths on different screen sizes.', 'louvre' ),
                        'field' => 'slider_drag',
                        'id'    => 'columns-medium',
                        'min'   => 2,
                        'max'   => 12,
                        'step'  => 1,
                        'std'   => 12,
                    ),                 

                    array(
                        'name'  => esc_html__( 'Column width on tablet portrait', 'louvre' ),
                        'desc'  => esc_html__( 'You can set different column widths on different screen sizes.', 'louvre' ),
                        'field' => 'slider_drag',
                        'min'   => 2,
                        'max'   => 12,
                        'step'  => 1,
                        'id'    => 'columns-small',
                        'std'   => 12,
                    ),

                    array(
                        'name'  => esc_html__( 'Column width on mobile portrait', 'louvre' ),
                        'desc'  => esc_html__( 'You can set different column widths on different screen sizes.', 'louvre' ),
                        'field' => 'slider_drag',
                        'id'    => 'columns-xsmall',
                        'min'   => 2,
                        'max'   => 12,
                        'step'  => 1,
                        'std'   => 12,
                    ),
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    self::get_setting( 'text-color' ),

                    array(
                        'name'  => esc_html__( 'Choose background color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'bg-color',
                        'std'   => 'rgba(255, 255, 255, 0)'
                    ),

                    self::get_setting( 'text-align' ),

                    self::get_setting( 'bg-video-mp' ),
                    self::get_setting( 'bg-video-webm' ),

                    self::get_setting( 'bg-img' ),
                    self::get_setting( 'bg-x' ),
                    self::get_setting( 'bg-y' ),
                    self::get_setting( 'bg-attachement' ),
                    self::get_setting( 'bg-repeat' ),
                    self::get_setting( 'bg-size' ),
                    self::get_setting( 'parallax' ),

                    self::get_setting( 'mask' ),
                    self::get_setting( 'mask-color' ),
                    self::get_setting( 'mask-gradient-color' ),
                    self::get_setting( 'gradient-type' ),

                    self::get_setting( 'border-top' ),
                    self::get_setting( 'border-top-width' ),
                    self::get_setting( 'border-top-color' ),

                    self::get_setting( 'border-bottom' ),
                    self::get_setting( 'border-bottom-width' ),
                    self::get_setting( 'border-bottom-color' ),

                    self::get_setting( 'border-left' ),
                    self::get_setting( 'border-left-width' ),
                    self::get_setting( 'border-left-color' ),

                    self::get_setting( 'border-right' ),
                    self::get_setting( 'border-right-width' ),
                    self::get_setting( 'border-right-color' ),             

                    self::get_setting( 'margin-top' ),
                    self::get_setting( 'margin-bottom' ),

                    self::get_setting( 'padding-top' ),
                    self::get_setting( 'padding-bottom' ),
                    self::get_setting( 'padding-left' ),
                    self::get_setting( 'padding-right' ),

                    array(
                        'name'  => esc_html__( 'Gutter right', 'louvre' ),
                        'desc'  => esc_html__( 'Columns have a default spacing to the right and left side of 20px. You can modify it to anything you need. (Not to be mistaked as padding, that is additional spacing)', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'gutter-right',
                        'std'   => 20
                    ),

                    array(
                        'name'  => esc_html__( 'Gutter left', 'louvre' ),
                        'desc'  => esc_html__( 'Columns have a default spacing to the right and left side of 20px. You can modify it to anything you need. (Not to be mistaked as padding, that is additional spacing)', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'gutter-left',
                        'std'   => 20
                    ),

                    array(
                        'name'  => esc_html__( 'Custom CSS', 'louvre' ),
                        'field' => 'textarea',
                        'id'    => 'custom-css',
                        'std'   => ''
                    )
                )
            )
        );
    }

    static function menu()
    {

        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Menu', 'louvre' ),
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-menu'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose your menu', 'louvre' ),
                        'field'   => 'select',
                        'options' => wp_list_pluck( wp_get_nav_menus(), 'name', 'slug' ),
                        'id'      => 'menu-id',
                        'std'     => ''
                    ),
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    array(
                        'name'    => esc_html__( 'Choose menu style', 'louvre' ),
                        'desc'    => esc_html__( 'The theme has different menu styles available for you to choose from. Make sure the containers you add them into have enough space.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'horizontal' => esc_html__( 'Horizontal menu', 'louvre' ),
                            'vertical'   => esc_html__( 'Vertical menu', 'louvre' ),
                            'fullscreen' => esc_html__( 'Fullscreen menu', 'louvre' ),
                            'logo'       => esc_html__( 'Menu with logo in the middle', 'louvre' ),
                            'sidebar'    => esc_html__( 'Sidebar menu', 'louvre' ),
                        ),
                        'id'           => 'styles',
                        'class_select' => 'airkit_trigger-options',
                        'std'          => 'horizontal',
                    ),

                    array(
                        'name'    => esc_html__( 'Show Submenu decoration', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y'     => esc_html__( 'Yes', 'louvre' ),
                            'n'     => esc_html__( 'No', 'louvre' ),
                        ),
                        'id'      => 'submenu-decoration',
                        'std'     => 'n',
                    ),

                    array(
                        'name'    => esc_html__( 'Show Menu label for toggle', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y'     => esc_html__( 'Yes', 'louvre' ),
                            'n'     => esc_html__( 'No', 'louvre' ),
                        ),
                        'id'           => 'label',
                        'class_select' => 'airkit_trigger-options',
                        'std'          => 'n',
                        'class'    => 'airkit_styles-fullscreen airkit_styles-sidebar',
                    ),

                    array(
                        'name'    => esc_html__( 'Upload custom logo', 'louvre' ),
                        'field'      => 'upload',
                        'media-type' => 'image',
                        'multiple'   => 'false',
                        'id'         => 'custom-logo',
                        'class'    => 'airkit_styles-logo',
                    ),

                    array(
                        'name'    => esc_html__( 'Choose text font option', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'std'     => esc_html__( 'Standard font', 'louvre' ),
                            'google'  => esc_html__( 'Google fonts', 'louvre' )
                        ),
                        'id'           => 'font-type',
                        'std'          => 'std',
                        'class_select' => 'airkit_trigger-options',
                    ),

                    array(
                        'name'  => esc_html__( 'Choose the text options', 'louvre' ),
                        'field' => 'typography',
                        'id'    => 'font',
                        'std'   => array(
                            'family'    => 'Open Sans',
                            'weight'    => 'normal',
                            'size'      => 14,
                            'style'     => 'normal',
                            'letter'    => 0,
                            'line'      => 'inherit',
                            'decor'     => 'none',
                            'transform' => 'none'
                        ),
                        'class' => 'airkit_styles-logo airkit_font-type-google'
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'custom-colors',
                        'std'   => 'y'
                    ),

                    // Menu Colors
                    array(
                        'name'  => esc_html__( 'Menu background color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'bg-color',
                        'std'   => 'rgba(255, 255, 255, 0)',
                        'class' => 'airkit_custom-colors-y'
                    ),

                    array(
                        'name'  => esc_html__( 'Menu background color on hover', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'bg-color-hover',
                        'std'   => 'rgba(255, 255, 255, 0)',
                        'class' => 'airkit_custom-colors-y'
                    ),

                    array(
                        'name'  => esc_html__( 'Menu text color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'text-color',
                        'std'   => '#000000',
                        'class' => 'airkit_custom-colors-y'
                    ),

                    array(
                        'name'  => esc_html__( 'Menu text color on hover', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'text-color-hover',
                        'std'   => '#000000',
                        'class' => 'airkit_custom-colors-y'
                    ),

                    array(
                        'name'  => esc_html__( 'Submenu background color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'submenu-bg-color',
                        'std'   => '#ffffff',
                        'class' => 'airkit_custom-colors-y'
                    ),

                    array(
                        'name'  => esc_html__( 'Submenu background color on hover', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'submenu-bg-color-hover',
                        'std'   => '#f8f8f8',
                        'class' => 'airkit_custom-colors-y'
                    ),

                    array(
                        'name'  => esc_html__( 'Submenu text color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'submenu-text-color',
                        'std'   => '#000000',
                        'class' => 'airkit_custom-colors-y'
                    ),

                    array(
                        'name'  => esc_html__( 'Submenu text color on hover', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'submenu-text-color-hover',
                        'std'   => '#000000',
                        'class' => 'airkit_custom-colors-y'
                    ),
                    //colors end.

                    self::get_setting( 'text-align' ),

                    array(
                        'name'    => esc_html__( 'Show icons in this menu', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'      => 'icons',
                        'std'     => 'y'
                    ),

                    array(
                        'name'    => esc_html__( 'Show description in this menu', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'      => 'description',
                        'std'     => 'y'
                    ),


                    array(
                        'name' => esc_html__( 'Add logo to menu', 'louvre' ),
                        'desc'  => esc_html__( 'If this option is set to yes, an logo element will be added to this menu', 'louvre' ),
                        'field' => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'add-logo',
                        'std'      => 'n',
                        'class_select' => 'airkit_trigger-options',
                    ),

                    array(
                        'name' => esc_html__( 'Where would you like to add logo element ?', 'louvre' ),
                        'desc'  => esc_html__( 'You may add selected element before or after the menu.', 'louvre' ),
                        'field' => 'select',
                        'options' => array(
                            'prepend' => esc_html__( 'Before menu', 'louvre' ),
                            'append'  => esc_html__( 'After menu', 'louvre' )
                        ),
                        'id'       => 'append-logo',
                        'std'      => 'prepend',
                        'class' => 'airkit_add-logo-y',                     
                    ),

                    array(
                        'name' => esc_html__( 'Add search element to menu', 'louvre' ),
                        'desc'  => esc_html__( 'If this option is set to yes, an search element will be added to this menu', 'louvre' ),
                        'field' => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'add-search',
                        'std'      => 'n',
                        'class_select' => 'airkit_trigger-options',                     
                    ),

                    array(
                        'name' => esc_html__( 'Where would you like to add Search element ?', 'louvre' ),
                        'desc'  => esc_html__( 'You may add selected element before or after the menu.', 'louvre' ),
                        'field' => 'select',
                        'options' => array(
                            'prepend' => esc_html__( 'Before menu', 'louvre' ),
                            'append'  => esc_html__( 'After menu', 'louvre' )
                        ),
                        'id'       => 'append-search',
                        'std'      => 'prepend',
                        'class' => 'airkit_add-search-y',                     
                    ),

                    /*
                     * Must check if WooCommerce class exists.
                     */
                    ( class_exists('WooCommerce') ? 
                            array(
                                'name' => esc_html__( 'Add WooCommerce cart to menu', 'louvre' ),
                                'desc'  => esc_html__( 'If this option is set to yes, WooCommerce cart will be added to this menu', 'louvre' ),
                                'field' => 'select',
                                'options' => array(
                                    'y' => esc_html__( 'Yes', 'louvre' ),
                                    'n' => esc_html__( 'No', 'louvre' )
                                ),
                                'id'       => 'add-cart',
                                'std'      => 'n',
                                'class_select' => 'airkit_trigger-options',                     
                            )

                        : false
                    ),  

                    ( class_exists('WooCommerce') ? 

                        array(
                            'name' => esc_html__( 'Where would you like to add Cart element ?', 'louvre' ),
                            'desc'  => esc_html__( 'You may add selected element before or after the menu.', 'louvre' ),
                            'field' => 'select',
                            'options' => array(
                                'prepend' => esc_html__( 'Before menu', 'louvre' ),
                                'append'  => esc_html__( 'After menu', 'louvre' )
                            ),
                            'id'       => 'append-cart',
                            'std'      => 'prepend',
                            'class' => 'airkit_add-cart-y',                     
                        )

                        : false
                    ),

                )
            )
        );
    }

    static function logo()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Logo', 'louvre' ),
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-logo'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose logo alignment', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'text-left'   => esc_html__( 'Left', 'louvre' ),
                            'text-center' => esc_html__( 'Center', 'louvre' ),
                            'text-right'  => esc_html__( 'Right', 'louvre' )
                        ),
                        'id'      => 'align',
                        'std'     => 'text-left'
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )                    
                )
            )
        );
    }

    static function user()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'User element', 'louvre' ),
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-user'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose alignment for user element', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'text-left'   => esc_html__( 'Left', 'louvre' ),
                            'text-right'  => esc_html__( 'Right', 'louvre' ),
                            'text-center' => esc_html__( 'Center', 'louvre' )
                        ),
                        'id'      => 'align',
                        'std'     => 'text-left'
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )                    
                )
            )
        );
    }

    static function social_buttons()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Social buttons', 'louvre' ),
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-social'
                    ),

                    self::get_setting( 'text-align' ),

                    array(
                        'name'    => esc_html__( 'Social buttons style', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'background' => esc_html__( 'Small, with background colors', 'louvre' ),
                            'bordered'   => esc_html__( 'Big, with border', 'louvre' ),
                            'iconed'     => esc_html__( 'Icons only', 'louvre' ),
                        ),
                        'id'      => 'style',
                        'std'     => 'background',
                    ),

                    array(
                        'name'    => esc_html__( 'Show social button labels', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'      => 'labels',
                        'std'     => 'n',
                    ),


                    array(
                        'name'    => esc_html__( 'Show RSS Button', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'      => 'rss',
                        'std'     => 'y',
                    ),

                    array(
                        'name'    => esc_html__( 'Add search button', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'      => 'search',
                        'std'     => 'n',
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )                    
                )
            )
        );
    }

    static function searchbox()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Search box', 'louvre' ),
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-search'
                    ),

                    array(
                       'name'    => esc_html__( 'Choose search element style', 'louvre' ),
                       'field'   => 'select',
                       'options' => array(
                           'icon'   => esc_html__( 'Icon', 'louvre' ),
                           'input'  => esc_html__( 'Input field', 'louvre' ),
                       ),
                       'id'      => 'style',
                       'std'     => 'icon'
                    ),

                    array(
                       'name'    => esc_html__( 'Enable Live search results?', 'louvre' ),
                       'field'   => 'select',
                       'options' => array(
                           'y'   => esc_html__( 'Yes', 'louvre' ),
                           'n'  => esc_html__( 'No', 'louvre' ),
                       ),
                       'id'      => 'live_results',
                       'std'     => 'y'
                    ),

                    array(
                       'name'    => esc_html__( 'Choose search element alignment', 'louvre' ),
                       'field'   => 'select',
                       'options' => array(
                           'left'   => esc_html__( 'Left', 'louvre' ),
                           'right'  => esc_html__( 'Right', 'louvre' ),
                           'center' => esc_html__( 'Center', 'louvre' )
                       ),
                       'id'      => 'align',
                       'std'     => 'text-left'
                   )
                )
            )
        );
    }

    static function clients()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Clients block', 'louvre' ),
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-clients'
                    ),

                    self::get_setting( 'per-row' ),

                    self::get_setting( 'carousel' ),
                    self::get_setting( 'carousel-nav' ),
                    self::get_setting( 'carousel-autoplay' ),                

                    array(
                        'name'     => esc_html__( 'Add new item', 'louvre' ),
                        'field'    => 'tmpl',
                        'options'  => array(

                            array(
                                'name'  => esc_html__( 'Title', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ),

                            array(
                                'name'       => esc_html__( 'Set a client image', 'louvre' ),
                                'field'      => 'upload',
                                'media-type' => 'image',
                                'multiple'   => 'false',
                                'id'         => 'image',
                                'std'        => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Enter client URL here', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'url',
                                'std'   => ''
                            ),

                            self::get_setting( 'reveal-effect' ),
                            self::get_setting( 'reveal-delay' ),                          
                        ),
                        'id'       => 'items',
                        'sortable' => 'true',
                        'std'      => array()
                    )
                )
            )
        );
    }

    static function features_block()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Icon box', 'louvre' ),
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-featured-area'
                    ),

                    self::get_setting( 'per-row' ),

                    array(
                        'name'    => esc_html__( 'Enable gutter (spacing) between icon boxes', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'gutter',
                        'std'      => 'y'
                    ),

                    array(
                        'name'     => esc_html__( 'Add new item', 'louvre' ),
                        'field'    => 'tmpl',
                        'id'       => 'items',
                        'sortable' => 'true',
                        'std'      => array(),
                        'options'  => array(

                            array(
                                'name'  => esc_html__( 'Item title', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ),

                            self::get_setting( 'icon' ),
                            self::get_setting( 'icon-color' ),

                            array(
                                'name'  => esc_html__( 'Title color', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'title-color',
                                'std'   => 'rgba(0,0,0,1)',
                                'desc'  => esc_html__( 'Choose color for the title inside icon box', 'louvre' ),
                            ),

                            array(
                                'name'  => esc_html__( 'Text color', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'text-color',
                                'std'   => 'rgba(0,0,0,0.8)',
                                'desc'  => esc_html__( 'Choose color for the text inside icon box', 'louvre' ),
                            ),

                            self::get_setting( 'bg-color' ),

                            array(
                                'name'  => esc_html__( 'Text color on hover', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'text-color-hover',
                                'std'   => 'rgba(255,255,255,1)',
                                'desc'  => esc_html__( 'Choose color for the text on icon box hover', 'louvre' ),
                            ),

                            array(
                                'name'  => esc_html__( 'Add your text here', 'louvre' ),
                                'field' => 'textarea',
                                'id'    => 'text',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add your URL here', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'url',
                                'std'   => ''
                            ),

                            self::get_setting( 'reveal-effect' ),
                            self::get_setting( 'reveal-delay' )
                        )
                    )
                )
            )
        );
    }

    static function listed_features()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Listed features', 'louvre' ),
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-list'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose icon alignment', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'above-title'  => esc_html__( 'Above title', 'louvre' ),
                            'text-left'  => esc_html__( 'Left', 'louvre' ),
                            'text-right' => esc_html__( 'Right', 'louvre' )
                        ),
                        'id'       => 'align',
                        'std'      => 'text-left'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose styling option', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'none'       => esc_html__( 'None', 'louvre' ),
                            'border'     => esc_html__( 'Border', 'louvre' ),
                            'background' => esc_html__( 'Background', 'louvre' )
                        ),
                        'id'           => 'color-style',
                        'std'          => 'none',
                        'class_select' => 'airkit_trigger-options'
                    ),               

                    array(
                        'name'     => esc_html__( 'Add new item', 'louvre' ),
                        'field'    => 'tmpl',
                        'id'       => 'items',
                        'sortable' => 'true',
                        'std'      => array(),
                        'options'  => array(

                            self::get_setting( 'icon' ),
                            self::get_setting( 'icon-color' ),

                            array(
                                'name'  => esc_html__( 'Add title', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add title URL here', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'url',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add your text here', 'louvre' ),
                                'field' => 'textarea',
                                'id'    => 'text',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Border color', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'border-color',
                                'std'   => '#DDDDDD',
                                'class' => 'airkit_color-style-border',
                            ),                 

                            array(
                                'name'  => esc_html__( 'Background color', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'bg-color',
                                'std'   => '#ffffff',
                                'class' => 'airkit_color-style-background',
                            ), 

                            array(
                                'name'         => esc_html__( 'Reveal effect', 'louvre' ),
                                'field'        => 'select',
                                'options'      => airkit_all_animations( 'effect' ),
                                'id'           => 'reveal-effect',
                                'std'          => 'none',
                                'class_select' => 'airkit_trigger-options'
                            ),

                            array(
                                'name'    => esc_html__( 'Reveal delay', 'louvre' ),
                                'field'   => 'select',
                                'options' => airkit_all_animations( 'delay' ),
                                'id'      => 'reveal-delay',
                                'std'     => 'delay-500',
                                'class'   => 'airkit_reveal-effect-none airkit_revert-trigger'
                            )
                        )
                    )
                )
            )
        );
    }

    static function icon()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Icon', 'louvre' ),
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-tick'
                    ),

                    self::get_setting( 'icon' ),
                    self::get_setting( 'icon-color' ),

                    array(
                        'name'  => esc_html__( 'Set an icon size in pixels', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'icon-size',
                        'std'   => 25
                    ),

                    array(
                        'name'    => esc_html__( 'Choose your icon align', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'left'   => esc_html__( 'Left', 'louvre' ),
                            'center' => esc_html__( 'Center', 'louvre' ),
                            'right'  => esc_html__( 'Right', 'louvre' )
                        ),
                        'id'      => 'icon-align',
                        'std'     => 'left'
                    ),
                    
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                    
                )
            )
        );
    }

    static function sidebar()
    {

        $main = array( 'main' => esc_html__( 'Main Sidebar', 'louvre' ), 'footer1' => esc_html__( 'Footer 1', 'louvre' ), 'footer2' => esc_html__( 'Footer 2', 'louvre' ), 'footer3' => esc_html__( 'Footer 3', 'louvre' ), 'footer4' => esc_html__( 'Footer 4', 'louvre' ) );

        $sidebars = get_option( 'louvre_sidebars', array() );

        $sidebars = array_merge( $main, $sidebars );

        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Sidebar', 'louvre' ),
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-sidebar'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose sidebar', 'louvre' ),
                        'field'   => 'select',
                        'options' => $sidebars,
                        'id'      => 'sidebar-id',
                        'std'     => 'main'
                    ),

                    array(
                        'name'    => esc_html__( 'Make sidebar sticky within container', 'louvre' ),
                        'desc'    => esc_html__( 'This will only work properly if within new row, with only a full row columns. If you place columns above or below, there might be errors on stick.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'      => 'sidebar-sticky',
                        'std'     => 'n'
                    )
                )
            )
        );
    }

    static function testimonials()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Testimonials', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-comments',
                    ),

                    self::get_setting( 'per-row' ),

                    self::get_setting( 'carousel' ),
                    self::get_setting( 'carousel-nav' ),
                    self::get_setting( 'carousel-scroll' ),
                    self::get_setting( 'carousel-autoplay' ),                 

                    array(
                        'name' => esc_html__( 'Choose testimonials block style', 'louvre' ),
                        'field' => 'select',
                        'options' => array(
                            'no-image'    => esc_html__( 'No image', 'louvre' ),
                            'image-above' => esc_html__( 'Image above content', 'louvre' ),
                            'image-left'  => esc_html__( 'Image to the left of content', 'louvre' ),
                            'image-below' => esc_html__( 'Image below content', 'louvre' ),
                        ),
                        'id'       => 'style',
                        'std'      => 'image-above',
                        'class_select' => 'airkit_trigger-options',
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                  

                    array(
                        'name'     => esc_html__( 'Add new testimonial', 'louvre' ),
                        'field'    => 'tmpl',
                        'options'  => array(

                            array(
                                'name'       => esc_html__( 'User image', 'louvre' ),
                                'field'      => 'upload',
                                'media-type' => 'image',
                                'multiple'   => 'false',
                                'id'         => 'image',
                                'std'        => '',
                                'class'      => 'airkit_style-no-image airkit_revert-trigger'
                            ),

                            array(
                                'name'  => esc_html__( 'Add your text here', 'louvre' ),
                                'field' => 'textarea',
                                'id'    => 'text',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add person name', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'name',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add company name', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'company',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add your URL here', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'url',
                                'std'   => ''
                            ),
                        ),
                        'id'       => 'items',
                        'sortable' => 'true',
                        'std'      => array()
                    )
                )
            ),
        );
    }

    static function callaction()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Call to action', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-direction'
                    ),

                    array(
                        'name'  => esc_html__( 'Call to action Text', 'louvre' ),
                        'field' => 'textarea',
                        'id'    => 'text',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Button Text', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'button-text',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Button Link', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'link',
                        'std'   => ''
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                  
                )
            )
        );
    }

    static function advertising()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Advertising element', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-money'
                    ),

                    array(
                        'name'  => esc_html__( 'Insert your advertising code in the textarea below', 'louvre' ),
                        'field' => 'textarea',
                        'id'    => 'advertising',
                        'std'   => ''
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                     
                )
            )
        );
    }

    static function delimiter()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Delimiter', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-delimiter'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose delimiter style', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'dotsslash'         => esc_html__( 'Dotsslash', 'louvre' ),
                            'doubleline'        => esc_html__( 'Double line', 'louvre' ),
                            'lines'             => esc_html__( 'Lines', 'louvre' ),
                            'squares'           => esc_html__( 'Squares', 'louvre' ),
                            'line'              => esc_html__( 'Line', 'louvre' ),
                            'gradient'          => esc_html__( 'Gradient', 'louvre' ),
                            'iconed icon-close' => esc_html__( 'Line with cross', 'louvre' ),
                            'small-line'        => esc_html__( 'Small 100px line', 'louvre' ),
                        ),
                        'id'     => 'type',
                        'std'    => 'doubleline'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose delimiter color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'color',
                        'std'   => '#FFFFFF'
                    )
                )
            )
        );
    }

    static function title()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Title', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-font'
                    ),

                    self::get_setting( 'icon' ),

                    array(
                        'name'  => esc_html__( 'Title', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'title',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Subtitle', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'subtitle',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Link', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'link',
                        'std'   => ''
                    ),

                    self::get_setting( 'target' )
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    array(
                        'name'    => esc_html__( 'Choose title style', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'simpleleft' => esc_html__( 'Title aligned left', 'louvre' ),
                            'lineafter' => esc_html__( 'Title aligned left with circle and line after', 'louvre' ),
                            'leftrect' => esc_html__( 'Title aligned left with rectangular left', 'louvre' ),
                            'simplecenter' => esc_html__( 'Title aligned center', 'louvre' ),
                            'smallcenter' => esc_html__( 'Small Title aligned center', 'louvre' ),
                            'linerect' => esc_html__( 'Title aligned center with line and rectangular below', 'louvre' ),
                            '2lines' => esc_html__( 'Title aligned center with 2 lines before and after', 'louvre' ),
                            'lineariconcenter' => esc_html__( 'Title aligned center with linear icon after', 'louvre' ),
                            'with-subtitle-above' => esc_html__( 'Title with subtitle above', 'louvre' ),
                            'align-right' => esc_html__( 'Title aligned right', 'louvre' ),
                            'brackets' => esc_html__( 'Title in brackets', 'louvre' ),
                            'with-small-line-below' => esc_html__( 'Title with small line below', 'louvre' ),
                            'with-double-line' => esc_html__( 'Title with double line after', 'louvre' ),
                            'with-bold-line-after' => esc_html__( 'Title with bold line after', 'louvre' ),
                            'border-square-left' => esc_html__( 'Title with bordered square left', 'louvre' ),
                            'border-square-center' => esc_html__( 'Title with bordered square center', 'louvre' ),
                            'kodak' => esc_html__( 'Title kodak style centered', 'louvre' ),
                        ),
                        'id'       => 'style',
                        'std'      => 'simpleleft',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    array(
                        'name'  => esc_html__( 'Letter spacing', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'letter-spacer',
                        'std'   => 0
                    ),

                    array(
                        'name'  => esc_html__( 'Choose title color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'title-color',
                        'std'   => airkit_get_color( 'general_text_color' )
                    ),

                    array(
                        'name'  => esc_html__( 'Choose subtitle color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'subtitle-color',
                        'std'   => airkit_get_color( 'general_text_color' )
                    ),

                    array(
                        'name'    => esc_html__( 'Choose title heading type', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'h1' => 'H1',
                            'h2' => 'H2',
                            'h3' => 'H3',
                            'h4' => 'H4',
                            'h5' => 'H5',
                            'h6' => 'H6',
                        ),
                        'id'       => 'size',
                        'std'      => 'h3',
                        'class'    => 'airkit_style-smallcenter airkit_revert-trigger',
                    ),

                    array(
                        'name'    => esc_html__( 'Choose subtitle font size', 'louvre' ),
                        'field'   => 'input',
                        'type'    => 'number',
                        'id'      => 'subtitle-size',
                        'std'     => 14
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                 
                )
            )
        );
    }

    static function video()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Video', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-video'
                    ),

                    array(
                        'name'    => esc_html__( 'Enable lightbox mode', 'louvre' ),
                        'desc'    => esc_html__( 'If yes is selected, it will only show a button. When clicked, it will show the video in a modal box.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'           => 'lightbox',
                        'std'          => 'n',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    array(
                        'name'  => esc_html__( 'Title', 'louvre' ),
                        'desc'  => esc_html__( 'Add a title/description for your video.', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'title',
                        'std'   => '',
                        'class' => 'airkit_lightbox-y'
                    ),

                    array(
                        'name'  => esc_html__( 'Add your URL here.', 'louvre' ),
                        'field' => 'textarea',
                        'id'    => 'embed',
                        'std'   => '',
                        'esc'   => array( 'airkit_Template', 'esc_text' )
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                 

                    array(
                        'name'  => esc_html__( 'Custom CSS', 'louvre' ),
                        'field' => 'textarea',
                        'id'    => 'custom-css',
                        'std'   => ''
                    )
                )
            )
        );
    }

    static function image()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Image', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-image'
                    ),

                    array(
                        'name'       => esc_html__( 'Upload you image in the media library and select it', 'louvre' ),
                        'field'      => 'upload',
                        'media-type' => 'image',
                        'multiple'   => 'false',
                        'id'         => 'image-url',
                        'std'        => ''
                    ),

                    array(
                        'name'    => esc_html__( 'Image align', 'louvre' ),
                        'desc'    => esc_html__( 'Choose the alignment of you image. If the image is smaller than the container, it will be contained to the dimensions of it. If it is smaller, it will be aligned to the selected position.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'left'   => esc_html__( 'Left', 'louvre' ),
                            'center' => esc_html__( 'Center', 'louvre' ),
                            'right'  => esc_html__( 'Right', 'louvre' )
                        ),
                        'id'       => 'align',
                        'std'      => 'left'
                    ),

                    array(
                        'name'  => esc_html__( 'Add a link to the image', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'forward-url',
                        'std'   => ''
                    ),

                    self::get_setting( 'target' ),

                    array(
                        'name'    => esc_html__( 'Use retina image', 'louvre' ),
                        'desc'    => esc_html__( 'This option will make you image 2x smaller. Note that this option uses the get_image_size() PHP function and some server can have it deactivated. If you get a notice, contact your hosting provider.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'retina',
                        'std'      => 'n'
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),

                    array(
                        'name'  => esc_html__( 'Custom CSS', 'louvre' ),
                        'field' => 'textarea',
                        'id'    => 'custom-css',
                        'std'   => ''
                    )
                )
            )
        );
    }

    static function spacer()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Spacer', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-resize-vertical'
                    ),

                    array(
                        'name'  => esc_html__( 'Spacer height', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'height',
                        'std'   => 30
                    )
                )
            )
        );
    }

    static function facebook_block()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Facebook', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-facebook'
                    ),

                    array(
                        'name'  => esc_html__( 'Insert the URL of your Facebook Page', 'louvre' ),
                        'desc'  => 'ex: http://facebook.com/touchsize',
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'url',
                        'std'   => ''
                    ),

                    array(
                        'name'    => esc_html__( 'Hide cover photo', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'true'  => esc_html__( 'Yes', 'louvre' ),
                            'false' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'cover',
                        'std'      => 'false'
                    )
                )
            )
        );
    }

    static function counter()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Counters', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-time'
                    ),

                    array(
                        'name'  => esc_html__( 'Text', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'counters-text',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Count percent (%)', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'counters-precents',
                        'std'   => 100
                    ),

                    self::get_setting( 'text-color' ),

                    array(
                        'name'    => esc_html__( 'Display track bar', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'with-track-bar'    => esc_html__( 'With track bar', 'louvre' ),
                            'without-track-bar' => esc_html__( 'Without track bar', 'louvre' )
                        ),
                        'id'           => 'track-bar',
                        'std'          => 'with-track-bar',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    array(
                        'name'  => esc_html__( 'Track bar color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'track-bar-color',
                        'std'   => '#000',
                        'class' => 'airkit_track-bar-with-track-bar'
                    ),

                    array(
                        'name'    => esc_html__( 'Select icon', 'louvre' ),
                        'field'   => 'list_select',
                        'options' => self::get_icons(),
                        'id'      => 'icon',
                        'std'     => 'heart',
                        'class'   => 'airkit_track-bar-without-track-bar'
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )
                )
            )
        );
    }

    static function buttons()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Button', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-button'
                    ),

                    array(
                        'name'  => esc_html__( 'Button text', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'text',
                        'std'   => 'Text button'
                    ),

                    array(
                        'name'  => esc_html__( 'URL', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'url',
                        'std'   => ''
                    ),

                    self::get_setting( 'target' ),

                    array(
                        'name'    => esc_html__( 'Choose button size', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'big'    => esc_html__( 'Big', 'louvre' ),
                            'medium' => esc_html__( 'Medium', 'louvre' ),
                            'small'  => esc_html__( 'Small', 'louvre' ),
                            'xsmall' => esc_html__( 'xSmall', 'louvre' )
                        ),
                        'id'      => 'size',
                        'std'     => 'medium'
                    ),
                    
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    self::get_setting( 'icon' ),

                    array(
                        'name'    => esc_html__( 'Choose icon align inside the button', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'left-of-text'  => esc_html__( 'Left of text', 'louvre' ),
                            'right-of-text' => esc_html__( 'Right of text', 'louvre' ),
                            'above-text'    => esc_html__( 'Above Text', 'louvre' )
                        ),
                        'id'      => 'icon-align',
                        'std'     => 'left-of-text'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose button align in container', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'text-left'    => esc_html__( 'Left', 'louvre' ),
                            'text-right'   => esc_html__( 'Right', 'louvre' ),
                            'text-center'  => esc_html__( 'Center', 'louvre' )
                        ),
                        'id'      => 'button-align',
                        'std'     => 'text-left'
                    ),

                    self::get_setting( 'text-color' ),

                    array(
                        'name'  => esc_html__( 'Button text color on hover', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'text-hover-color',
                        'std'   => '#FFFFFF'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose button style', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'border-button'     => esc_html__( 'Border button', 'louvre' ),
                            'background-button' => esc_html__( 'Background button', 'louvre' ),
                            'ghost-button'      => esc_html__( 'Ghost button', 'louvre' )
                        ),
                        'id'           => 'mode-display',
                        'std'          => 'background-button',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose border color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'border-color',
                        'std'   => '#DDDDDD',
                        'class' => 'airkit_mode-display-border-button airkit_mode-display-ghost-button'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose background color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'bg-color',
                        'std'   => '#ffffff',
                        'class' => 'airkit_mode-display-background-button'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose background color on hover', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'bg-hover-color',
                        'std'   => '#f1f1f1',
                        'class' => 'airkit_mode-display-background-button airkit_mode-display-ghost-button'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose border color on hover', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'border-hover-color',
                        'std'   => '#f1f1f1',
                        'class' => 'airkit_mode-display-border-button'
                    )
                )
            )
        );
    }

    static function contact_form()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Contact form', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-mail'
                    ),

                    array(
                        'name'    => esc_html__( 'Disable email icon', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'hide-icon',
                        'std'      => 'n'
                    ),

                    array(
                        'name'    => esc_html__( 'Disable name field', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'hide-name',
                        'std'      => 'n'
                    ),

                    array(
                        'name'    => esc_html__( 'Disable email field', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'hide-email',
                        'std'      => 'n'
                    ),

                    array(
                        'name'    => esc_html__( 'Disable subject field', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'hide-subject',
                        'std'      => 'n'
                    ),

                    array(
                        'name'    => esc_html__( 'Disable text field', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'hide-text',
                        'std'      => 'n'
                    ),

                    array(
                        'name'     => esc_html__( 'Add New Field', 'louvre' ),
                        'field'    => 'tmpl',
                        'options'  => array(

                            array(
                                'name'    => esc_html__( 'Choose your type field', 'louvre' ),
                                'field'   => 'select',
                                'options' => array(
                                    'select'   => esc_html__( 'Select', 'louvre' ),
                                    'input'    => esc_html__( 'Input', 'louvre' ),
                                    'textarea' => esc_html__( 'Textarea', 'louvre' )
                                ),
                                'id'           => 'type',
                                'std'          => 'Input',
                                'class_select' => 'airkit_trigger-options'
                            ),

                            array(
                                'name'    => esc_html__( 'Make field required', 'louvre' ),
                                'field'   => 'select',
                                'options' => array(
                                    'y' => esc_html__( 'Yes', 'louvre' ),
                                    'n' => esc_html__( 'No', 'louvre' )
                                ),
                                'id'       => 'required',
                                'std'      => 'Input'
                            ),

                            array(
                                'name'  => esc_html__( 'Field title', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Write your options here in the following field(ex: option1/option2/options3/...)', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'options',
                                'std'   => '',
                                'class' => 'airkit_type-select'
                            )
                        ),
                        'id'       => 'items',
                        'sortable' => 'true',
                        'std'      => array()
                    )
                )
            )
        );
    }

    static function featured_area()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Featured area', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-featured-area'
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),
                )
            ),
            
            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(
                    array(

                        'name'    => esc_html__( 'Layout', 'louvre' ),
                        'desc'    => esc_html__( 'Choose featured area style', 'louvre' ),
                        'field'   => 'img_selector',
                        'options' => array(
                            'style-1' => 'One big post, three small',
                            'style-2' => 'One big post, four small',
                            'style-3' => 'Big post with thumbnails',
                        ),
                        'img' => array(
                            'style-1' => 'feat_area_1.png',
                            'style-2' => 'feat_area_2.png',
                            'style-3' => 'feat_area_3.png',

                        ),
                        'id'  => 'style',
                        'std' => 'style-1',                     
                    ),
                ),             
            ),
        );
    }

    static function shortcodes()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Shortcode', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-code'
                    ),

                    array(
                        'name'    => esc_html__( 'Remove default container column paddings', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'paddings',
                        'std'      => 'n'
                    ),

                    array(
                        'name'  => esc_html__( 'Insert your shortcode', 'louvre' ),
                        'field' => 'textarea',
                        'id'    => 'shortcodes',
                        'std'   => ''
                    )
                )
            )
        );
    }

    static function image_carousel()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Image carousel', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow'
                    ),

                    array(
                        'name'  => esc_html__( 'Maximum carousel height (px)', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'carousel-height',
                        'std'   => 400
                    ),

                    array(
                        'name'       => esc_html__( 'Choose images', 'louvre' ),
                        'field'      => 'upload',
                        'media-type' => 'image',
                        'multiple'   => 'true',
                        'sortable'   => 'true',
                        'id'         => 'bg-image',
                        'std'        => ''
                    )
                )
            )
        );
    }

    static function grid()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Grid view articles', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),
                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'portfolio_categories' ),
                    self::get_setting( 'tags' ),

                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),

                    self::get_setting( 'pagination' ),            
                    self::get_setting( 'small-posts' ),                      
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    self::get_setting( 'behavior' ),
                    self::get_setting( 'carousel-nav' ),
                    self::get_setting( 'carousel-scroll' ),
                    self::get_setting( 'carousel-autoplay' ),
                    self::get_setting( 'per-row' ),

                    array(
                        'name'    => esc_html__( 'Enable featured image', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'featimg',
                        'std'      => 'y'
                    ),

                    self::get_setting( 'enable-ads' ),
                    self::get_setting( 'ads-step' ),                    

                    array(
                        'name'    => esc_html__( 'Choose title position', 'louvre' ),
                        'desc'    => esc_html__( 'Select your title position for you grid posts. You can either have it above the image of above the excerpt. Note that sometimes title may change the position of the meta: date, categories, author as well.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'above-image' => esc_html__( 'Above image', 'louvre' ),
                            'below-image' => esc_html__( 'Above excerpt', 'louvre' )
                        ),
                        'id'       => 'title-position',
                        'std'      => 'below-image'
                    ),

                    self::get_setting( 'styling' ),
                    self::get_setting( 'bg-color' ),
                    self::get_setting( 'border-color' ),
                    self::get_setting( 'excerpt' ),
                    self::get_setting( 'meta' ),
                    self::get_setting( 'gutter-space' ),
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )                    
                )
            )
        );
    }

    static function list_view()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'List view articles', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'portfolio_categories' ),
                    self::get_setting( 'tags' ),

                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),

                    self::get_setting( 'pagination' )
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    array(
                        'name'    => esc_html__( 'Post excerpt style', 'louvre' ),
                        'desc'    => esc_html__( 'You can remove the preview text used in List view if you don\'t need it, or you can choose what to display as preview text for the posts. If you choose to display excerpt, the excerpt (generated or defined) of the post will be displayed. If you choose to display content, entire content of the post will be displayed. If you choose Hide option, nor excerpt or content will be displayed.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'excerpt' => esc_html__( 'Show excerpt', 'louvre' ),
                            'content' => esc_html__( 'Show content', 'louvre' ),
                            'hide'    => esc_html__( 'Hide', 'louvre' )
                        ),
                        'id'      => 'exc',
                        'std'     => 'excerpt'
                    ),
                    
                    self::get_setting( 'enable-ads' ),
                    self::get_setting( 'ads-step' ),    

                    self::get_setting( 'meta' ),
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                 
                )
            )
        );
    }

    static function numbered_list_view()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Numbered list view articles', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'portfolio_categories' ),
                    self::get_setting( 'tags' ),

                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),

                    self::get_setting( 'pagination' )
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(   
                    self::get_setting( 'per-row' ),
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                 
                )
            )
        );
    }

    static function thumbnail()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Thumbnail articles', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'portfolio_categories' ),
                    self::get_setting( 'tags' ),

                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),

                    self::get_setting( 'pagination' ),
                    self::get_setting( 'small-posts' ),                 

                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    self::get_setting( 'behavior' ),
                    /* Get carousel settings fields */
                    self::get_setting( 'carousel-nav' ),
                    self::get_setting( 'carousel-scroll' ),
                    self::get_setting( 'carousel-autoplay' ),                 
                    self::get_setting( 'per-row' ),

                    self::get_setting( 'enable-ads' ),
                    self::get_setting( 'ads-step' ),  

                    array(
                        'name'    => esc_html__( 'Choose title position', 'louvre' ),
                        'desc'    => esc_html__( 'Select your title position for you grid posts. You can either have it above the image of above the excerpt. Note that sometimes title may change the position of the meta: date, categories, author as well.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'above-image' => esc_html__( 'Above image', 'louvre' ),
                            'over-image'  => esc_html__( 'Over image', 'louvre' ),
                            'below-image' => esc_html__( 'Below image', 'louvre' )
                        ),
                        'id'       => 'title-position',
                        'std'      => 'below-image',
                        'class_select' => 'airkit_trigger-options',
                    ),

                    array(
                        'name'    => esc_html__( 'Choose content alignment', 'louvre' ),
                        'desc'    => esc_html__( 'You can choose to show title and meta centered or on the left.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'left'   => esc_html__( 'Left', 'louvre' ),
                            'center'  => esc_html__( 'Center', 'louvre' ),
                        ),
                        'id'       => 'text-align',
                        'std'      => 'center',
                        'class' => 'airkit_title-position-over-image',
                    ),

                    array(
                        'name' => esc_html__( 'How to display content', 'louvre' ),
                        'desc' => esc_html__( 'If you choose to always show content, posts title, categories and other meta will be always visible. If you choose to show content on hover, posts meta will be visible only when user hovers an article', 'louvre' ),
                        'field' => 'select',
                        'options' => array(
                            'show-always' => esc_html__( 'Display always', 'louvre' ),
                            'show-hover'  => esc_html__( 'Display on hover', 'louvre' ),
                        ),
                        'id'  => 'content-hover',
                        'std' => 'show-always',
                        'class' => 'airkit_title-position-over-image',
                    ),

                    self::get_setting( 'styling' ),
                    self::get_setting( 'bg-color' ),
                    self::get_setting( 'border-color' ),
                    self::get_setting( 'meta' ),
                    self::get_setting( 'gutter-space' ),
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )                    
                )
            )
        );
    }

    static function big()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Big posts articles', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'portfolio_categories' ),
                    self::get_setting( 'tags' ),
                    
                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),

                    self::get_setting( 'pagination' ),
                    self::get_setting( 'small-posts' ),                 

                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    array(
                        'name'    => esc_html__( 'Choose split layout', 'louvre' ),
                        'desc'    => esc_html__( 'You can select the split size for your big posts layout. You can have the image smaller with more attention to the title and excerpt or go the other way and have a bigger space for images.', 'louvre' ),
                        'field'   => 'img_selector',
                        'options' => array(
                            '1-3' => '1/3',
                            '1-2' => '1/2',
                            '3-4' => '3/4'
                        ),
                        'img' => array(
                            '1-3' => 'big_posts_13.png',
                            '1-2' => 'big_posts_12.png',
                            '3-4' => 'big_posts_34.png'
                        ),
                        'id'           => 'content-split',
                        'std'          => 'normal',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose image position', 'louvre' ),
                        'desc'    => esc_html__( 'You can select the positioning of the image for this element. You can align the image on left and content on the right or the other way. The mosaic option will show one post with image left and the next one with image right', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'left'   => esc_html__( 'Image left, content right', 'louvre' ),
                            'right'  => esc_html__( 'Image right, content left', 'louvre' ),
                            'mosaic' => esc_html__( 'Mosaic - alternate other options', 'louvre' )
                        ),
                        'id'       => 'image-position',
                        'std'      => 'left'
                    ),

                    array(
                        'name'    => esc_html__( 'Content horizontal align', 'louvre' ),
                        'desc'    => esc_html__( 'You can select the text alignment within the big post text section.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'left'   => esc_html__( 'Align left', 'louvre' ),
                            'center'  => esc_html__( 'Align center', 'louvre' ),
                        ),
                        'id'       => 'text-align',
                        'std'      => 'center'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose posts behavior', 'louvre' ),
                        'desc'    => esc_html__( 'You can choose to activate the carousel option so that each post will be a new slide', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'none'      => esc_html__( 'None', 'louvre' ),
                            'carousel'  => esc_html__( 'Carousel', 'louvre' ),
                        ),
                        'id'  => 'behavior',
                        'std' => 'none',
                        'class_select' => 'airkit_trigger-options',
                    ),

                    /* Get carousel settings fields */
                    self::get_setting( 'carousel-nav' ),
                    self::get_setting( 'carousel-autoplay' ),

                    self::get_setting( 'enable-ads' ),
                    self::get_setting( 'ads-step' ),                      

                    self::get_setting( 'styling' ),
                    self::get_setting( 'bg-color' ),
                    self::get_setting( 'border-color' ),
                    self::get_setting( 'meta' ),
                    self::get_setting( 'excerpt' ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )                    
                )
            )
        );
    }

    static function super()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Super posts articles', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'portfolio_categories' ),
                    self::get_setting( 'tags' ),
                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),
          
                    self::get_setting( 'pagination' ),
                    self::get_setting( 'small-posts' ),                 

                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(
                    self::get_setting( 'per-row' ),

                     array(
                        'name'    => esc_html__( 'Choose posts behavior', 'louvre' ),

                        'desc'    => esc_html__( 'Choose your posts behavior - you can have them just shown, or you can activate the carousel. If carousel is selected your articles will show up in a line with arrows for navigation. ', 'louvre' ),
                        'field'   => 'img_selector',

                        'options' => array(
                            'normal'   => 'normal',
                            'carousel' => 'carousel',
                            'filters'  => 'filters'

                        ),

                        'img' => array(
                            'normal'   => 'behavior_none.png',
                            'carousel' => 'behavior_carousel.png',
                            'filters'  => 'behavior_tabs.png'
                        ),

                        'id'           => 'behavior',
                        'std'          => 'normal',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    /* Get carousel settings fields */
                    self::get_setting( 'carousel-nav' ),
                    self::get_setting( 'carousel-scroll' ),
                    self::get_setting( 'carousel-autoplay' ),                          
                    
                    self::get_setting( 'gutter-space' ),
                    self::get_setting( 'meta' ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )                         
                )
            )
        );
    }

    static function category()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Category view articles', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'portfolio_categories' ),
                    self::get_setting( 'tags' ),

                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    array(
                        'name'    => esc_html__( 'Style', 'louvre' ),
                        'desc'    => esc_html__( 'Choose style for category view', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'style-1' => esc_html__( 'Style 1', 'louvre' ),
                            'style-2' => esc_html__( 'Style 2', 'louvre' ),
                            'style-3' => esc_html__( 'Style 3', 'louvre' )
                        ),
                        'id'       => 'style',
                        'std'      => 'style-1',
                    ),                 
                    self::get_setting( 'meta' ),
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ) 

                )
            )
        );
    }

    static function category_grids()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Category grids', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'portfolio_categories' ),
                    self::get_setting( 'tags' ),

                    self::get_setting( 'per-row' ),

                    array(
                        'name'  => esc_html__( 'Posts to extract', 'louvre' ),
                        'desc'  => esc_html__( 'This is the number of posts that will be displayed for each individual category you have selected.', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'posts-limit',
                        'std'   => 4
                    ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Category heading', 'louvre' ),
                'options' => array(
                    
                    array(
                        'name'    => esc_html__( 'Show category title and description', 'louvre' ),
                        'desc'    => esc_html__( 'If enabled, it will show the category title with link to the archive page.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'show-title',
                        'std'      => 'y',
                        'class_select' => 'airkit_trigger-options'
                    ),  

                    array(
                        'name'  => esc_html__( 'Letter spacing', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'letter-spacer',
                        'std'   => 0,
                        'class' => 'airkit_show-title-y'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose title color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'title-color',
                        'std'   => airkit_get_color( 'general_text_color' ),
                        'class' => 'airkit_show-title-y'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose subtitle color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'subtitle-color',
                        'std'   => airkit_get_color( 'general_text_color' ),
                        'class' => 'airkit_show-title-y'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose title heading type', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'h1' => 'H1',
                            'h2' => 'H2',
                            'h3' => 'H3',
                            'h4' => 'H4',
                            'h5' => 'H5',
                            'h6' => 'H6',
                        ),
                        'id'       => 'size',
                        'std'      => 'h3',
                        'class'    => 'airkit_show-title-y'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose title style', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'simpleleft' => esc_html__( 'Title aligned left', 'louvre' ),
                            'lineafter' => esc_html__( 'Title aligned left with circle and line after', 'louvre' ),
                            'leftrect' => esc_html__( 'Title aligned left with rectangular left', 'louvre' ),
                            'simplecenter' => esc_html__( 'Title aligned center', 'louvre' ),
                            'smallcenter' => esc_html__( 'Small Title aligned center', 'louvre' ),
                            'linerect' => esc_html__( 'Title aligned center with line and rectangular below', 'louvre' ),
                            '2lines' => esc_html__( 'Title aligned center with 2 lines before and after', 'louvre' ),
                            'lineariconcenter' => esc_html__( 'Title aligned center with linear icon after', 'louvre' ),
                            'with-subtitle-above' => esc_html__( 'Title with subtitle above', 'louvre' ),
                            'align-right' => esc_html__( 'Title aligned right', 'louvre' ),
                            'brackets' => esc_html__( 'Title in brackets', 'louvre' ),
                            'with-small-line-below' => esc_html__( 'Title with small line below', 'louvre' ),
                            'with-double-line' => esc_html__( 'Title with double line after', 'louvre' ),
                            'with-bold-line-after' => esc_html__( 'Title with bold line after', 'louvre' ),
                            'border-square-left' => esc_html__( 'Title with bordered square left', 'louvre' ),
                            'border-square-center' => esc_html__( 'Title with bordered square center', 'louvre' ),
                            'kodak' => esc_html__( 'Title kodak style centered', 'louvre' ),
                        ),
                        'id'       => 'style',
                        'std'      => 'simpleleft',
                        'class'    => 'airkit_show-title-y'
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ) 

                )
            )
        );
    }

    static function list_categories()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'List categories', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'portfolio_categories' ),
                    self::get_setting( 'tags' ),

                    array(
                        'name'      => esc_html__( 'Layout style', 'louvre' ),
                        'field'     => 'select',
                        'id'        => 'layout-style',
                        'options'   => array(
                            'over-image' => esc_html__('Text over image','louvre'),
                            'below-image' => esc_html__('Text below image','louvre'),
                        ),
                        'std'       => 'over-image'
                    ),
                    
                    self::get_setting( 'per-row' ),

                )
            ),
        );
    }

    static function small_articles()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Small articles', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'portfolio_categories' ),
                    self::get_setting( 'tags' ),

                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),
                    self::get_setting( 'pagination' ),
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    self::get_setting( 'per-row' ),

                     array(
                        'name'    => esc_html__( 'Choose post behavior', 'louvre' ),

                        'desc'    => esc_html__( 'Choose your posts behavior - you can have them just shown, or you can activate the carousel. If carousel is selected your articles will show up in a line with arrows for navigation. ', 'louvre' ),
                        'field'   => 'img_selector',

                        'options' => array(
                            'normal'   => 'normal',
                            'carousel' => 'carousel',
                            'filters'  => 'filters'

                        ),

                        'img' => array(
                            'normal'   => 'behavior_none.png',
                            'carousel' => 'behavior_carousel.png',
                            'filters'  => 'behavior_tabs.png'
                        ),

                        'id'           => 'behavior',
                        'std'          => 'normal',
                        'class_select' => 'airkit_trigger-options'
                    ),              

                    /* Get carousel settings fields */
                    self::get_setting( 'carousel-nav' ),
                    self::get_setting( 'carousel-scroll' ),
                    self::get_setting( 'carousel-autoplay' ),            
                     
                    self::get_setting( 'meta' ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )                                
                   
                )
            )
        );
    }    

    static function timeline()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Timeline view articles', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),

                    self::get_setting( 'meta' ),

                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),
                    self::get_setting( 'pagination' ),           

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),   
                )
            )
        );
    }

    static function mosaic()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Mosaic view articles', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),
                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'portfolio_categories' ),
                    self::get_setting( 'tags' ),

                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),
                    self::get_setting( 'pagination' )
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(


                    array(
                            'name'    => esc_html__( 'Choose post behavior', 'louvre' ),

                            'desc'    => esc_html__( 'Choose your posts behavior - you can have them just shown, or you can activate the carousel. If carousel is selected your articles will show up in a line with arrows for navigation.', 'louvre' ),
                            'field'   => 'img_selector',

                            'options' => array(
                                'normal'   => 'normal',
                                'carousel' => 'carousel',
                                'scroll'   => 'scroll',
                                'filters'  => 'filters'

                            ),

                            'img' => array(
                                'normal'   => 'behavior_none.png',
                                'carousel' => 'behavior_carousel.png',
                                'scroll'   => 'behavior_scroll.png',
                                'filters'  => 'behavior_tabs.png'
                            ),

                            'id'           => 'behavior',
                            'std'          => 'normal',
                            'class_select' => 'airkit_trigger-options'
                    ),

                    /* Get carousel settings fields */
                    self::get_setting( 'carousel-nav' ),
                    self::get_setting( 'carousel-autoplay' ),                 

                    array(
                        'name'    => esc_html__( 'Choose style of images', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'rectangles' => esc_html__( 'Rectangles', 'louvre' ),
                            'square'     => esc_html__( 'Squares', 'louvre' ),
                            'style-3'    => esc_html__( 'Style 3', 'louvre' ),
                            'style-4'    => esc_html__( 'Style 4', 'louvre' ),
                        ),
                        'id'           => 'layout',
                        'std'          => 'rectangles',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose number of rows', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            2 => 2,
                            3 => 3
                        ),
                        'id'       => 'rows',
                        'std'      => 'y',
                        'class'    => 'airkit_layout-rectangles'
                    ),

                    array(
                        'name'  => esc_html__( 'Posts to extract', 'louvre' ),
                        'desc'  => esc_html__( 'This is the number of posts that will be extracted from the database and shown in total. If you use pagination, this will be the default posts number and on each new iteration this number of posts will be extracted again.', 'louvre' ),
                        'field' => 'slider_drag',
                        'type'  => 'number',
                        'id'    => 'posts-limit',
                        'min'   => 6,
                        'max'   => 60,
                        'step'  => 6,
                        'std'   => 6,
                    ),                 

                    array(
                        'name'    => esc_html__( 'Enable spacing between posts', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'gutter',
                        'std'      => 'y'
                    ),

                    array(
                        'name'    => esc_html__( 'How to display post content', 'louvre' ),
                        'desc'    => esc_html__( 'If you choose Display always, post title, categories and excerpt will be always visible. If you choose to display them on hover, they will only show up when user hovers the article.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'always' => esc_html__( 'Display always', 'louvre' ),
                            'hover'  => esc_html__( 'Display on hover', 'louvre' ),
                        ),
                        'id'           => 'hover-style',
                        'std'          => 'always',
                        'class'        => 'airkit_layout-style-4 airkit_revert-trigger',
                    ),                 

                    self::get_setting( 'meta' ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),
                )
            )
        );
    }

    static function teams()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Team members', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-team'
                    ),

                    array(
                        'name'         => esc_html__( 'Choose your members category', 'louvre' ),
                        'field'        => 'select',
                        'options'      => wp_list_pluck( get_categories( array( 'hide_empty' => 1, 'taxonomy' => 'teams' ) ), 'cat_name', 'slug' ),
                        'id'           => 'category',
                        'class_select' => 'ts-custom-select-input',
                        'multiple'     => true,
                        'std'          => ''
                    ),

                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'per-row' ),
                    self::get_setting( 'carousel' ),
                    self::get_setting( 'carousel-nav' ),
                    self::get_setting( 'carousel-scroll' ),
                    self::get_setting( 'carousel-autoplay' ),                      

                    array(
                        'name'    => esc_html__( 'Remove spacing (gutter) between articles', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'remove-gutter',
                        'std'      => 'n'
                    ),
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )                    
                )
            )
        );
    }

    static function map()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Map', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-pin'
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                  

                    array(
                        'field' => 'render_map'
                    ),

                    array(
                        'name'  => esc_html__( 'Map width', 'louvre' ),
                        'desc'  => esc_html__( 'Enter the width number ( percent ). Eg: 100%', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'width',
                        'attr'  => 'max="100"',
                        'std'   => 100
                    ),

                    array(
                        'name'  => esc_html__( 'Map height', 'louvre' ),
                        'desc'  => esc_html__( 'Enter the height number ( px ) Eg: 400px', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'height',
                        'std'   => 300
                    ),

                    array(
                        'name'  => esc_html__( 'Latitude', 'louvre' ),
                        'desc'  => esc_html__( 'Latitude automatically generated from the address entered above.', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'latitude',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Longitude', 'louvre' ),
                        'desc'  => esc_html__( 'Longitude automatically generated from the address entered above.', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'longitude',
                        'std'   => ''
                    ),

                    array(
                        'name'    => esc_html__( 'Map type', 'louvre' ),
                        'desc'    => esc_html__( 'For details read the documentation from Google ', 'louvre' ) . '<a href="https://developers.google.com/maps/documentation/javascript/maptypes#MapTypes" target="_blank">' . esc_html__( 'read documentation', 'louvre' ) . '</a>',
                        'field'   => 'select',
                        'options' => array(
                            'ROADMAP'   => esc_html__( 'Roadmap', 'louvre' ),
                            'SATELLITE' => esc_html__( 'Satellite', 'louvre' ),
                            'HYBRID'    => esc_html__( 'Hybrid', 'louvre' ),
                            'TERRAIN'   => esc_html__( 'Terrain', 'louvre' )
                        ),
                        'id'      => 'type',
                        'std'     => 'ROADMAP'
                    ),

                    array(
                        'name'    => esc_html__( 'Map style', 'louvre' ),
                        'desc'    => esc_html__( 'For details read the documentation from Google ', 'louvre' ) . '<a href="https://developers.google.com/maps/documentation/javascript/maptypes#MapTypes" target="_blank">' . esc_html__( 'read documentation', 'louvre' ) . '</a>',
                        'field'   => 'select',
                        'options' => array(
                            'map-style-default'          => esc_html__( 'Default', 'louvre' ),
                            'map-style-essence'          => esc_html__( 'Essence', 'louvre' ),
                            'map-style-subtle-grayscale' => esc_html__( 'Subtle grayscale', 'louvre' ),
                            'map-style-shades-of-grey'   => esc_html__( 'Shades of grey', 'louvre' ),
                            'map-style-purple'           => esc_html__( 'Purple', 'louvre' ),
                            'map-style-best-ski-pros'    => esc_html__( 'Best ski pros', 'louvre' )
                        ),
                        'id'      => 'style',
                        'std'     => 'ROADMAP'
                    ),

                    array(
                        'name'  => esc_html__( 'Map zoom', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'zoom',
                        'std'   => 11
                    ),

                    array(
                        'name'    => esc_html__( 'Map type control', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'false' => esc_html__( 'Disable', 'louvre' ),
                            'true'  => esc_html__( 'Enable', 'louvre' )
                        ),
                        'id'      => 'control',
                        'std'     => 'true'
                    ),

                    array(
                        'name'    => esc_html__( 'Map zoom control', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'false' => esc_html__( 'Disable', 'louvre' ),
                            'true'  => esc_html__( 'Enable', 'louvre' )
                        ),
                        'id'      => 'zoom-control',
                        'std'     => 'true'
                    ),

                    array(
                        'name'    => esc_html__( 'Map scale control', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'false' => esc_html__( 'Disable', 'louvre' ),
                            'true'  => esc_html__( 'Enable', 'louvre' )
                        ),
                        'id'      => 'scale-control',
                        'std'     => 'false'
                    ),

                    array(
                        'name'    => esc_html__( 'Map scroll wheel', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'false' => esc_html__( 'Disable', 'louvre' ),
                            'true'  => esc_html__( 'Enable', 'louvre' )
                        ),
                        'id'      => 'scroll-wheel',
                        'std'     => 'true'
                    ),

                    array(
                        'name'    => esc_html__( 'Draggable directions', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'false' => esc_html__( 'Disable', 'louvre' ),
                            'true'  => esc_html__( 'Enable', 'louvre' )
                        ),
                        'id'      => 'draggable-direction',
                        'std'     => 'true'
                    ),

                    array(
                        'name'    => esc_html__( 'Marker icon', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'map-marker-icon-default' => esc_html__( 'Use default', 'louvre' ),
                            'map-marker-icon-upload'  => esc_html__( 'Upload icon', 'louvre' )
                        ),
                        'id'           => 'marker-icon',
                        'std'          => 'map-marker-icon-default',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    array(
                        'name'       => esc_html__( 'Upload custom marker icon', 'louvre' ),
                        'field'      => 'upload',
                        'media-type' => 'image',
                        'id'         => 'marker-img',
                        'std'        => '',
                        'class'      => 'airkit_marker-icon-map-marker-icon-upload'
                    )
                )
            )
        );
    }

    static function banner()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Banner', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-link-ext'
                    ),

                    array(
                        'name'       => esc_html__( 'Choose banner image', 'louvre' ),
                        'field'      => 'upload',
                        'media-type' => 'image',
                        'id'         => 'img',
                        'std'        => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Set banner height', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'height',
                        'std'   => 400
                    ),

                    array(
                        'name'  => esc_html__( 'Add your title', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'title',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Add banner text', 'louvre' ),
                        'field' => 'textarea',
                        'id'    => 'description',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Add text button', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'button-title',
                        'std'   => 'Go to'
                    ),

                    array(
                        'name'  => esc_html__( 'Add URL for button', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'button-url',
                        'std'   => ''
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                 
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    array(
                        'name'    => esc_html__( 'Choose button align', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'left'   => esc_html__( 'Left', 'louvre' ),
                            'right'  => esc_html__( 'Right', 'louvre' ),
                            'center' => esc_html__( 'Center', 'louvre' ),
                        ),
                        'id'  => 'text-align',
                        'std' => 'center'
                    ),                 

                    self::get_setting( 'bg-color' ),
                    self::get_setting( 'text-color' ),

                    array(
                        'name'  => esc_html__( 'Choose text color for button', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'button-text-color',
                        'std'   => '#FFFFFF'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose background color for button', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'button-background',
                        'std'   => '#000000'
                    ),
                
                )
            )            
        );
    }

    static function toggle()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Toggle', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-resize-full'
                    ),

                    array(
                        'name'  => esc_html__( 'Add title', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'title',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Add text', 'louvre' ),
                        'field' => 'textarea',
                        'id'    => 'description',
                        'std'   => ''
                    ),

                    array(
                        'name'    => esc_html__( 'Default toggle state', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'open'   => esc_html__( 'Open', 'louvre' ),
                            'closed' => esc_html__( 'Closed', 'louvre' )
                        ),
                        'id'       => 'state',
                        'std'      => 'closed'
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                 
                )
            )
        );
    }

    static function tab()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Tab', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-tabs'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose tab style', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'horizontal' => esc_html__( 'Horizontal', 'louvre' ),
                            'vertical'   => esc_html__( 'Vertical', 'louvre' )
                        ),
                        'id'       => 'mode',
                        'std'      => 'horizontal'
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                 

                    array(
                        'name'     => esc_html__( 'Add new tab', 'louvre' ),
                        'field'    => 'tmpl',
                        'options'  => array(

                            array(
                                'name'  => esc_html__( 'Add title', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add content', 'louvre' ),
                                'field' => 'textarea',
                                'id'    => 'text',
                                'std'   => ''
                            )
                        ),
                        'id'       => 'items',
                        'sortable' => 'true',
                        'std'      => array()
                    )
                )
            )
        );
    }

    static function cart()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Shopping cart', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-basket'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose shopping cart alignment', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'left'   => esc_html__( 'Left', 'louvre' ),
                            'center' => esc_html__( 'Center', 'louvre' ),
                            'right'  => esc_html__( 'Right', 'louvre' ),
                        ),
                        'id'      => 'align',
                        'std'     => 'left'
                    )
                )
            )
        );
    }

    static function timeline_features()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Timeline features', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-parallel'
                    ),

                    array(
                        'name'     => esc_html__( 'Add new timeline feature', 'louvre' ),
                        'field'    => 'tmpl',
                        'id'       => 'items',
                        'sortable' => 'true',
                        'std'      => array(),
                        'options'  => array(

                            array(
                                'name'  => esc_html__( 'Add title', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add content', 'louvre' ),
                                'field' => 'textarea',
                                'id'    => 'text',
                                'std'   => ''
                            ),

                            array(
                                'name'       => esc_html__( 'Add image', 'louvre' ),
                                'field'      => 'upload',
                                'media-type' => 'image',
                                'id'         => 'image',
                                'std'        => ''
                            ),

                            array(
                                'name'    => esc_html__( 'Choose image alignment', 'louvre' ),
                                'field'   => 'select',
                                'options' => array(
                                    'left'  => esc_html__( 'Left', 'louvre' ),
                                    'right' => esc_html__( 'Right', 'louvre' )
                                ),
                                'id'      => 'align',
                                'std'     => 'left'
                            ),

                            self::get_setting( 'reveal-effect' ),
                            self::get_setting( 'reveal-delay' )
                        )
                    )
                )
            )
        );
    }

    static function ribbon()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Ribbon banner', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-ribbon'
                    ),

                    array(
                        'name'  => esc_html__( 'Add title', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'title',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Add content', 'louvre' ),
                        'field' => 'textarea',
                        'id'    => 'text',
                        'std'   => ''
                    ),

                    array(
                        'name'    => esc_html__( 'Choose icon', 'louvre' ),
                        'field'   => 'list_select',
                        'options' => self::get_icons(),
                        'id'      => 'button-icon',
                        'std'     => ''
                    ),

                    array(
                        'name'       => esc_html__( 'Choose background image', 'louvre' ),
                        'field'      => 'upload',
                        'media-type' => 'image',
                        'id'         => 'image',
                        'std'        => ''
                    ),                 

                    array(
                        'name'  => esc_html__( 'Button text', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'button-text',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Button URL', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'button-url',
                        'std'   => ''
                    ),

                    self::get_setting( 'target' ),

                    array(
                        'name'    => esc_html__( 'Choose button size', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'big' => esc_html__( 'Big', 'louvre' ),
                            'medium' => esc_html__( 'Medium', 'louvre' ),
                            'small'  => esc_html__( 'Small', 'louvre' ),
                            'xsmall' => esc_html__( 'xSmall', 'louvre' )
                        ),
                        'id'      => 'button-size',
                        'std'     => 'medium'
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                 
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    self::get_setting( 'text-color' ),

                    array(
                        'name'  => esc_html__( 'Choose ribbon background color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'background',
                        'std'   => '#FFFFFF'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose ribbon alignment', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'ribbon-left'   => esc_html__( 'Left', 'louvre' ),
                            'ribbon-center' => esc_html__( 'Center', 'louvre' ),
                            'ribbon-right'  => esc_html__( 'Right', 'louvre' ),
                        ),
                        'id'      => 'align',
                        'std'     => 'ribbon-left'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose button alignment', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'text-left'   => esc_html__( 'Left', 'louvre' ),
                            'text-center' => esc_html__( 'Center', 'louvre' ),
                            'text-right'  => esc_html__( 'Right', 'louvre' ),
                        ),
                        'id'      => 'button-align',
                        'std'     => 'text-left'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose button style', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'border-button'     => esc_html__( 'Border button', 'louvre' ),
                            'background-button' => esc_html__( 'Background button', 'louvre' )
                        ),
                        'id'      => 'button-mode-display',
                        'std'     => 'background-button',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose button background color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'button-background-color',
                        'std'   => '#FFFFFF',
                        'class' => 'airkit_button-mode-display-background-button'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose button background color on hover', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'background-hover-color',
                        'std'   => '#333333',
                        'class' => 'airkit_button-mode-display-background-button'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose button border color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'button-border-color',
                        'std'   => '#FFFFFF',
                        'class' => 'airkit_button-mode-display-border-button'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose button border color on hover', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'border-hover-color',
                        'std'   => '#333333',
                        'class' => 'airkit_button-mode-display-border-button'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose button text color', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'button-text-color',
                        'std'   => '#333333'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose button text color on hover', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'text-hover-color',
                        'std'   => '#FFFFFF'
                    )
                )
            )
        );
    }

    static function count_down()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Countdown timer', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-megaphone'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose countdown style', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'small' => esc_html__( 'Small', 'louvre' ),
                            'big'   => esc_html__( 'Big', 'louvre' )
                        ),
                        'id'       => 'style',
                        'std'      => 'small'
                    ),

                    array(
                        'name'  => esc_html__( 'Add title', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'title',
                        'std'   => ''
                    ),

                    array(
                        'name'  => 'Date: (yyyy/mm/dd)',
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'date',
                        'std'   => ''
                    ),

                    array(
                        'name'  => 'Time: (hh:mm)',
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'hours',
                        'std'   => ''
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )                    
                )
            )
        );
    }

    static function powerlink()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Powerlink', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-ticket'
                    ),

                    array(
                        'name'       => esc_html__( 'Choose image URL', 'louvre' ),
                        'field'      => 'upload',
                        'media-type' => 'image',
                        'id'         => 'image',
                        'std'        => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Add title', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'title',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Add Button text', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'button-text',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Add Button URL', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'button-url',
                        'std'   => ''
                    ),
                    
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )                    
                )
            )
        );
    }

    static function calendar()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Calendar', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-calendar'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose calendar cell size', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'big'   => esc_html__( 'Big', 'louvre' ),
                            'small' => esc_html__( 'Small', 'louvre' )
                        ),
                        'id'       => 'size',
                        'std'      => 'small'
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),
                )
            )
        );
    }

    static function alert()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Alert', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-attention'
                    ),

                    self::get_setting( 'icon' ),

                    array(
                        'name'  => esc_html__( 'Add title', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'title',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Add text', 'louvre' ),
                        'field' => 'textarea',
                        'id'    => 'text',
                        'std'   => ''
                    ),

                    self::get_setting( 'bg-color' ),
                    self::get_setting( 'text-color' ),
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                   
                )
            )
        );
    }

    static function skills()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Skills', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-pencil-alt'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose skills style', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'horizontal' => esc_html__( 'Horizontal', 'louvre' ),
                            'vertical'   => esc_html__( 'Vertical', 'louvre' )
                        ),
                        'id'       => 'display-mode',
                        'std'      => 'horizontal'
                    ),

                    array(
                        'name'     => esc_html__( 'Add new item', 'louvre' ),
                        'field'    => 'tmpl',
                        'id'       => 'items',
                        'sortable' => 'true',
                        'std'      => array(),
                        'options'  => array(

                            array(
                                'name'  => esc_html__( 'Add title', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add percentage', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'number',
                                'id'    => 'percentage',
                                'std'   => 86
                            ),

                            array(
                                'name'  => esc_html__( 'Add color', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'color',
                                'std'   => '#777'
                            )
                        )
                    )
                )
            )
        );
    }

    static function accordion()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Article accordion', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-clipboard'
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' )
                )
            )
        );
    }

    static function chart_line()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Line chart', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-chart'
                    ),

                    array(
                        'name'  => esc_html__( 'Labels in format :"label1,label2,label3,..."', 'louvre' ),
                        'desc'  => esc_html__( 'Write the labels you will use for your chart. These are the labels standing at the bottom of the chart.', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'label',
                        'std'   => ''
                    ),

                    array(
                        'name'  => esc_html__( 'Add title', 'louvre' ),
                        'desc'  => esc_html__( 'Add a description for your chart.', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'title',
                        'std'   => ''
                    ),

                    array(
                        'name'    => esc_html__( 'Show lines across the chart', 'louvre' ),
                        'desc'    => esc_html__( 'Do you want the chart to have lines in the background? It is easier for the eye to look up for information.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'true'  => esc_html__( 'Yes', 'louvre' ),
                            'false' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'    => 'scaleShowGridLines',
                        'std'   => 'false'
                    ),

                    array(
                        'name'  => esc_html__( 'Color of the grid lines', 'louvre' ),
                        'desc'  => esc_html__( 'Change the color of the grid lines.', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'scaleGridLineColor',
                        'std'   => '#f7f7f7'
                    ),

                    array(
                        'name'  => esc_html__( 'Width of the grid lines (INTEGER)', 'louvre' ),
                        'desc'  => esc_html__( 'The lines in the background can be very thin or thick. You decide the way you need them.', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'scaleGridLineWidth',
                        'std'   => 1
                    ),

                    array(
                        'name'    => esc_html__( 'Show horizontal lines (except X axis)', 'louvre' ),
                        'desc'    => esc_html__( 'Choose wether you want horizontal lines.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'true'  => esc_html__( 'Yes', 'louvre' ),
                            'false' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'    => 'scaleShowHorizontalLines',
                        'std'   => 'true'
                    ),

                    array(
                        'name'    => esc_html__( 'Show vertical lines (except Y axis)', 'louvre' ),
                        'desc'    => esc_html__( 'Choose wether you want vertical lines.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'true'  => esc_html__( 'Yes', 'louvre' ),
                            'false' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'    => 'scaleShowVerticalLines',
                        'std'   => 'true'
                    ),

                    array(
                        'name'    => esc_html__( 'The line is curved between points', 'louvre' ),
                        'desc'    => esc_html__( 'Do you want the lines (you will add the values below) to be curved between the value points or just straight lines.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'true'  => esc_html__( 'Yes', 'louvre' ),
                            'false' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'    => 'bezierCurve',
                        'std'   => 'true'
                    ),

                    array(
                        'name'  => esc_html__( 'Tension of the bezier curve between points (0.1 - 1)', 'louvre' ),
                        'desc'  => esc_html__( 'How curved do you want the lines to be bended.', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'bezierCurveTension',
                        'std'   => 0.4
                    ),

                    array(
                        'name'    => esc_html__( 'Show a dot for each point', 'louvre' ),
                        'desc'    => esc_html__( 'You can add dots for the values in your chart.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'true'  => esc_html__( 'Yes', 'louvre' ),
                            'false' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'    => 'pointDot',
                        'std'   => 'true'
                    ),

                    array(
                        'name'  => esc_html__( 'Radius of each point dot in pixels (INTEGER)', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'pointDotRadius',
                        'std'   => 4
                    ),

                    array(
                        'name'  => esc_html__( 'Pixel width of point dot stroke (INTEGER)', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'pointDotStrokeWidth',
                        'std'   => 1
                    ),

                    array(
                        'name'  => esc_html__( 'Amount extra to add to the radius to cater for hit detection outside the drawn point (INTEGER)', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'pointHitDetectionRadius',
                        'std'   => 20
                    ),

                    array(
                        'name'    => esc_html__( 'Show a stroke for datasets', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'true'  => esc_html__( 'Yes', 'louvre' ),
                            'false' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'    => 'datasetStroke',
                        'std'   => 'true'
                    ),

                    array(
                        'name'  => esc_html__( 'Pixel width of dataset stroke (INTEGER)', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'datasetStrokeWidth',
                        'std'   => 2
                    ),

                    array(
                        'name'    => esc_html__( 'Fill the dataset with a colour', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'true'  => esc_html__( 'Yes', 'louvre' ),
                            'false' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'    => 'datasetFill',
                        'std'   => 'true'
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                 

                    array(
                        'name'     => esc_html__( 'Add New Line', 'louvre' ),
                        'field'    => 'tmpl',
                        'id'       => 'items',
                        'sortable' => 'true',
                        'std'      => array(),
                        'options'  => array(

                            array(
                                'name'  => esc_html__( 'Title', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Fill color', 'louvre' ),
                                'desc'  => esc_html__( 'Choose a color to fill the value dataset with.', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'fillColor',
                                'std'   => '#ffffff'
                            ),

                            array(
                                'name'  => esc_html__( 'Stroke color', 'louvre' ),
                                'desc'  => esc_html__( 'Choose a stroke color.', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'strokeColor',
                                'std'   => '#ffffff'
                            ),

                            array(
                                'name'  => esc_html__( 'Point color', 'louvre' ),
                                'desc'  => esc_html__( 'Choose a color for the points of the values on the chart.', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'pointColor',
                                'std'   => '#ffffff'
                            ),

                            array(
                                'name'  => esc_html__( 'Point stroke color', 'louvre' ),
                                'desc'  => esc_html__( 'Choose a stroke (border) color', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'pointStrokeColor',
                                'std'   => '#ffffff'
                            ),

                            array(
                                'name'  => esc_html__( 'Point highlight fill', 'louvre' ),
                                'desc'  => esc_html__( 'The fill color of the point on the chart.', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'pointHighlightFill',
                                'std'   => '#777'
                            ),

                            array(
                                'name'  => esc_html__( 'Point highlight stroke', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'pointHighlightStroke',
                                'std'   => '#ffffff'
                            ),

                            array(
                                'name'  => esc_html__( 'Data in format 25,35,45,...', 'louvre' ),
                                'desc'  => esc_html__( 'Set the values for this line. Make sure you add the values in the exact order as the labels above. For example if you have the labels: label1,label2,label3 here you set the values for them in the same order: valueForLabelOne,valueForLabelTwo,valueForLabelThree', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'data',
                                'std'   => ''
                            ),
                        )
                    )
                )
            )
        );
    }

    static function chart_pie()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Pie chart', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-chart'
                    ),

                    array(
                        'name'    => esc_html__( 'Show a stroke on each segment', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'true'  => esc_html__( 'Yes', 'louvre' ),
                            'false' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'    => 'segmentShowStroke',
                        'std'   => 'true',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    array(
                        'name'  => esc_html__( 'The color of each segment stroke', 'louvre' ),
                        'field' => 'input_color',
                        'id'    => 'segmentStrokeColor',
                        'std'   => '#fff',
                        'class' => 'airkit_segmentShowStroke-true'
                    ),

                    array(
                        'name'  => esc_html__( 'The width of each segment stroke (INTEGER)', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'segmentStrokeWidth',
                        'std'   => 2,
                        'class' => 'airkit_segmentShowStroke-true'
                    ),

                    array(
                        'name'  => esc_html__( 'The percentage of the chart that we cut out of the middle (INTEGER)', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'percentageInnerCutout',
                        'std'   => 50,
                    ),

                    array(
                        'name'  => esc_html__( 'Amount of animation steps (INTEGER)', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'animationSteps',
                        'std'   => 100,
                    ),

                    array(
                        'name'    => esc_html__( 'Animate the rotation of the Doughnut', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'true'  => esc_html__( 'Yes', 'louvre' ),
                            'false' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'    => 'animateRotate',
                        'std'   => 'true',
                        'class' => 'airkit_mode-pie'
                    ),

                    array(
                        'name'    => esc_html__( 'Animate scaling the Doughnut from the centre', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'true'  => esc_html__( 'Yes', 'louvre' ),
                            'false' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'    => 'animateScale',
                        'std'   => 'false',
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                 

                    array(
                        'name'     => esc_html__( 'Add New Item', 'louvre' ),
                        'field'    => 'tmpl',
                        'id'       => 'items',
                        'sortable' => 'true',
                        'std'      => array(),
                        'class'    => 'airkit_mode-pie',
                        'options'  => array(

                            array(
                                'name'  => esc_html__( 'Label', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Value (INTEGER)', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'number',
                                'id'    => 'value',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Section background color', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'color',
                                'std'   => '#777'
                            ),

                            array(
                                'name'  => esc_html__( 'Section background color on hover', 'louvre' ),
                                'field' => 'input_color',
                                'id'    => 'highlight',
                                'std'   => '#777'
                            ),
                        )
                    )
                )
            )
        );
    }

    static function gallery()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Gallery', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-gallery'
                    ),

                    array(
                        'name'  => esc_html__( 'Choose gallery style', 'louvre' ), 
                        'field'   => 'select',
                        'options' => array(
                            'masonry'    => esc_html__( 'Masonry', 'louvre' ),
                            'horizontal' => esc_html__( 'Horizontal scroll', 'louvre' ),
                            'carousel' => esc_html__( 'Carousel', 'louvre' ),
                        ),
                        'id'       => 'style',
                        'std'      => 'masonry',
                        'class_select' => 'airkit_trigger-options',
                    ),

                    'per-row' => array(
                        'name'    => esc_html__( 'Number of elements per row', 'louvre' ),
                        'desc'    => esc_html__( 'Choose the number of elements you want to use per line. For example, if you want a grid of 3 items choose the 3 columns layout', 'louvre' ),
                        'field'   => 'img_selector',
                        'options' => array(
                            1 => 1,
                            2 => 2,
                            3 => 3,
                            4 => 4,
                            6 => 6
                        ),
                        'img' => array(
                            1 => 'per_row_1.png',
                            2 => 'per_row_2.png',
                            3 => 'per_row_3.png',
                            4 => 'per_row_4.png',
                            6 => 'per_row_6.png',
                        ),
                        'id'       => 'per-row',
                        'std'      => 2,
                        'class'    => 'airkit_style-masonry'
                    ),

                    array(
                        'name'       => esc_html__( 'Upload images', 'louvre' ),
                        'field'      => 'upload',
                        'media-type' => 'image',
                        'multiple'   => 'true',
                        'id'         => 'images',
                        'std'        => ''
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Image sizes', 'louvre' ),
                'options' => array(
                    array(
                        'name'    => esc_html__( 'Width', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'      => 'width',
                        'std'     => '1000',
                    ),

                    array(
                        'name'    => esc_html__( 'Height', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'      => 'height',
                        'std'     => '650',
                        'class'   => 'airkit_style-horizontal'
                    ), 
                ),             
            ),         
        );
    }

    static function nona()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Nona post slider', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-gallery'
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                 
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Image sizes', 'louvre' ),
                'options' => array(
                    array(
                        'name'  => esc_html__( 'Width', 'louvre' ),
                        'desc'  => esc_html__( 'In this field you may set custom width for slider images.', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'      => 'width',
                        'std'     => '800',
                    ),

                    array(
                        'name'  => esc_html__( 'Height', 'louvre' ),
                        'desc'  => esc_html__( 'In this field you may set custom height for slider images.', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'      => 'height',
                        'std'     => '450',
                    ), 
                ),             
            ),         
        );
    }

    static function boca()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Boca post slider', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-gallery'
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                 
                )
            )
        );
    }

    static function grease()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Grease post slider', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-gallery'
                    ),

                    self::get_setting( 'post-type' ),
                    self::get_setting( 'post-format' ),
                    self::get_setting( 'category' ),
                    self::get_setting( 'gallery_categories' ),
                    self::get_setting( 'videos_categories' ),
                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'rated' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),

                    array(
                        'name'    => esc_html__( 'Choose slider style', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'zoom-in'   => esc_html__( 'ZoomIn Effect', 'louvre' ),
                            'classic' => esc_html__( 'Classic', 'louvre' ),
                        ),
                        'id'      => 'style',
                        'std'     => 'zoom-in'
                    ),
                    array(
                        'name'    => esc_html__( 'Enable slider autoplay', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y'   => esc_html__( 'Yes', 'louvre' ),
                            'n'   => esc_html__( 'No', 'louvre' ),
                        ),
                        'id'      => 'autoplay',
                        'std'     => 'n'
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                 
                )
            ),
            
        );
    }

    static function breadcrumbs()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Breadcrumbs', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-gallery'
                    )
                )
            )
        );
    }

    static function text()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Text', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-text'
                    ),

                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' ),                  

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'text',
                        'std'   => '',
                        'esc'   => array( 'airkit_Template', 'esc_text' )
                    ),
                )
            )
        );
    }

    static function pricing_tables()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Pricing tables', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-dollar'
                    ),

                    self::get_setting( 'per-row' ),
                    self::get_setting( 'gutter-space' ),

                    array(
                        'name'     => esc_html__( 'Add new item', 'louvre' ),
                        'field'    => 'tmpl',
                        'id'       => 'items',
                        'sortable' => 'true',
                        'std'      => array(),
                        'options'  => array(

                            array(
                                'name'  => esc_html__( 'Add title', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ), 

                            array(
                                'name'  => esc_html__( 'Add price', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'price',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add description', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'description',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add features', 'louvre' ),
                                'desc'  => esc_html__( 'Add pricing table features, one per line', 'louvre' ),
                                'field' => 'textarea',
                                'id'    => 'items',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add period', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'period',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Button URL', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'button-url',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Button text', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'button-text',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Set as featured (most popular)', 'louvre' ),
                                'field'   => 'select',
                                'options' => array(
                                    'y' => esc_html__( 'Yes', 'louvre' ),
                                    'n' => esc_html__( 'No', 'louvre' )
                                ),
                                'id'    => 'featured',
                                'std'   => 'n'
                            ),

                            self::get_setting( 'reveal-effect' ),
                            self::get_setting( 'reveal-delay' ),
                        )
                    )
                )
            ),
        );
    } 

    static function pricelist()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Pricelist', 'louvre' ),
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-dollar'
                    ),

                    self::get_setting( 'per-row' ),

                    array(
                        'name'    => esc_html__( 'Pricelist items style', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'image' => esc_html__( 'Item with image', 'louvre' ),
                            'icon'  => esc_html__( 'Item with icon', 'louvre' ),
                            'none'  => esc_html__( 'Item with text only', 'louvre' ),
                        ),
                        'id'      => 'style',
                        'std'     => 'image',
                        'class_select' => 'airkit_trigger-options'
                    ),                 

                    array(
                        'name'     => esc_html__( 'Add new item', 'louvre' ),
                        'field'    => 'tmpl',
                        'id'       => 'items',
                        'sortable' => 'true',
                        'std'      => array(),
                        'options'  => array(

                            array(
                                'name'  => esc_html__( 'Item title', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ),

                            array(
                                'name'    => esc_html__( 'Choose an icon', 'louvre' ),
                                'field'   => 'list_select',
                                'options' => self::get_icons(),
                                'id'      => 'icon',
                                'std'     => 'icon-noicon',
                                'class'   => 'airkit_style-icon'
                            ),

                            array(
                                'name'       => esc_html__( 'Upload image for this item', 'louvre' ),
                                'field'      => 'upload',
                                'media-type' => 'image',
                                'multiple'   => 'false',
                                'id'         => 'image',
                                'std'        => '',
                                'class'      => 'airkit_style-image'
                            ),                         

                            array(
                                'name'  => esc_html__( 'Add description for this item', 'louvre' ),
                                'field' => 'textarea',
                                'id'    => 'text',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add price for this item', 'louvre' ),
                                'field' => 'input',
                                'id'    => 'price',
                                'type'  => 'text',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Enable modal for this item', 'louvre' ),
                                'desc'  => esc_html__( 'When you click on item the modal will appear with extended content.', 'louvre' ),
                                'field'   => 'select',
                                'options' => array(
                                    'y' => esc_html__( 'Yes', 'louvre' ),
                                    'n' => esc_html__( 'No', 'louvre' )
                                ),
                                'id'    => 'modal',
                                'std'   => 'n'
                            ),

                            array(
                                'name'  => esc_html__( 'Extended content for item', 'louvre' ),
                                'field' => 'textarea',
                                'id'    => 'extended-text',
                                'std'   => '',
                            ),

                            array(
                                'name'  => esc_html__( 'Add your URL here', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'url',
                                'std'   => ''
                            ),

                            self::get_setting( 'reveal-effect' ),
                            self::get_setting( 'reveal-delay' ),
                        )
                    )
                )
            )
        );
    }


    static function slider()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Slider', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-desktop'
                    ),

                    array(
                        'name'    => esc_html__( 'Choose slider type', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'tilter-slider' => esc_html__( 'Tilter slider', 'louvre' ),
                            'flexslider'  => esc_html__( 'Flex slider', 'louvre' ),
                            'slicebox'    => esc_html__( 'Slicebox', 'louvre' ),
                            'bxslider'    => esc_html__( 'bxSlider', 'louvre' ),
                            'parallax'    => esc_html__( 'Parallax slider', 'louvre' ),
                            'stream'      => esc_html__( 'Stream slider', 'louvre' ),
                            'corena'      => esc_html__( 'Corena slider', 'louvre' ),
                            'klein'       => esc_html__( 'Klein slider', 'louvre' ),
                            'vertical-slider'  => esc_html__( 'Vertical thumbs slider', 'louvre' ),
                        ),
                        'id'           => 'type',
                        'std'          => 'flexslider',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    array(
                        'name'    => esc_html__( 'Slider source', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'latest-posts'              => esc_html__( 'Latest posts', 'louvre' ),
                            'latest-galleries'          => esc_html__( 'Latest galleries', 'louvre' ),
                            'latest-videos'             => esc_html__( 'Latest videos', 'louvre' ),
                            'custom-slides'             => esc_html__( 'Custom slides', 'louvre' ),
                        ),
                        'id'           => 'source',
                        'std'          => 'latest-posts',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    array(
                        'name'  => esc_html__( 'Posts to extract', 'louvre' ),
                        'desc'  => esc_html__( 'This is the number of posts that will be extracted from the database and shown in total. If you use pagination, this will be the default posts number and on each new iteration this number of posts will be extracted again.', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'    => 'posts-limit',
                        'std'   => 4,
                        'class' => 'airkit_source-custom-slides airkit_revert-trigger'
                    ),

                    array(
                        'name'         => esc_html__( 'Tilt Hover Effect', 'louvre' ),
                        'desc'         => esc_html__( 'Hover animations with a fancy tilt effect for each slide items.', 'louvre' ),
                        'field'        => 'select',
                        'options'      => array(
                            'y'        => esc_html__('Yes','louvre'),
                            'n'        => esc_html__('No','louvre'),
                        ),
                        'id'           => 'tilt-hover-effect',
                        'std'          => 'y',
                        'class'        => 'airkit_type-tilter-slider'
                    ),

                    array(
                        'name'    => esc_html__( 'Show only featured posts', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'featured',
                        'std'      => 'n',
                        'class'   => 'airkit_source-custom-slides airkit_revert-trigger'
                    ),

                    array(
                        'name'     => esc_html__( 'Add new item', 'louvre' ),
                        'field'    => 'tmpl',
                        'id'       => 'items',
                        'sortable' => 'true',
                        'class'    => 'airkit_source-custom-slides',
                        'std'      => array(),
                        'options'  => array(

                            array(
                                'name'  => esc_html__( 'Add title', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add slide URL', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'url',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Add Title for slide URL', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'url-title',
                                'std'   => ''
                            ),                         

                            array(
                                'name'  => esc_html__( 'Add content', 'louvre' ),
                                'field' => 'textarea',
                                'id'    => 'text',
                                'std'   => ''
                            ),

                            self::get_setting( 'text-align' ),

                            array(
                                'name'       => esc_html__( 'Choose your slide image', 'louvre' ),
                                'field'      => 'upload',
                                'media-type' => 'image',
                                'multiple'   => 'false',
                                'id'         => 'image-url',
                                'std'        => '',
                            )
                        )
                    )
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Image sizes', 'louvre' ),
                'options' => array(

                    array(
                        'name'    => esc_html__( 'Width for large screens', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'      => 'width',
                        'std'     => '1200',
                    ),

                    array(
                        'name'    => esc_html__( 'Height for large screens', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'      => 'height',
                        'std'     => '450',
                    ), 

                    array(
                        'name'    => esc_html__( 'Width for small screens', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'      => 'width-sm',
                        'std'     => '400',
                    ),

                    array(
                        'name'    => esc_html__( 'Height for small screens', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'number',
                        'id'      => 'height-sm',
                        'std'     => '280',
                    ),                 
                ),             
            ),
        );
    }    

    static function events()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Events', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-text'
                    ),

                    array(
                        'name'         => esc_html__( 'Choose event category', 'louvre' ),
                        'field'        => 'select',
                        'options'      => wp_list_pluck( get_categories( array( 'hide_empty' => 1, 'taxonomy' => 'event_categories' ) ), 'cat_name', 'slug' ),
                        'id'           => 'event_categories',
                        'class_select' => 'ts-custom-select-input',
                        'multiple'     => true,
                        'std'          => ''
                    ),

                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'featured' ),
                    self::get_setting( 'post__not_in' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'posts_per_page' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'order' ),
                    self::get_setting( 'pagination' ),
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )                         
                )
            )
        );
    }

    static function list_products() 
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'List products', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),

                    array(
                        'name'         => esc_html__( 'Choose product categories', 'louvre' ),
                        'desc'         => esc_html__( 'Choose the categories that you want to showcase products from.', 'louvre' ),
                        'field'        => 'select',
                        'options'      => wp_list_pluck( get_categories( array( 'hide_empty' => 0, 'taxonomy' => 'product_cat', 'pad_counts' => true ) ), 'cat_name', 'slug' ),
                        'id'           => 'product_cat',
                        'class_select' => 'ts-custom-select-input',
                        'multiple'     => true,
                        'std'          => ''
                    ),
                    
                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'orderby' ),
                    self::get_setting( 'offset' ),
                    self::get_setting( 'order' ),
                    self::get_setting( 'pagination' )
                )
            ),

            'styles' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Styles', 'louvre' ),
                'options' => array(

                    array(
                        'name'    => esc_html__( 'Choose products behavior', 'louvre' ),
                        'desc'    => esc_html__( 'Choose your posts behavior - you can have them just shown, or you can activate the carousel. If carousel is selected your articles will show up in a line with arrows for navigation. If masonry bahevior is selected - your articles will be arranged in to fit it. Be aware that activating the masonry option the crop settings for image sizes tab will be overwritten.', 'louvre' ),
                        'field'   => 'img_selector',
                        'options' => array(
                            'normal'   => 'normal',
                            'carousel' => 'carousel',
                            'masonry'  => 'masonry',

                        ),
                        'img' => array(
                            'normal'   => 'behavior_none.png',
                            'carousel' => 'behavior_carousel.png',
                            'masonry'  => 'behavior_masonry.png',
                        ),

                        'id'           => 'behavior',
                        'std'          => 'normal',
                        'class_select' => 'airkit_trigger-options'
                    ),

                    self::get_setting( 'carousel-nav' ),
                    self::get_setting( 'carousel-scroll' ),
                    self::get_setting( 'carousel-autoplay' ),                   

                    self::get_setting( 'per-row' ),
                    self::get_setting( 'reveal-effect' ),
                    self::get_setting( 'reveal-delay' )                    
                )
            )
        );        
    }

    static function list_users() 
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'List users', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-users',
                    ),

                    array(
                        'name'         => esc_html__( 'Criteria', 'louvre' ),
                        'desc'         => esc_html__( 'Users will show by specific criteria that you have selected.', 'louvre' ),
                        'field'        => 'select',
                        'options'      => array(
                            'latest'       => esc_html__('Latest','louvre'),
                            'most-posts'   => esc_html__('Number of posts','louvre'),
                            'top-rated'    => esc_html__('Top rated','louvre'),
                            'most-liked'   => esc_html__('Most liked','louvre'),
                        ),
                        'id'           => 'criteria',
                        'std'          => 'latest'
                    ),
                    
                    self::get_setting( 'posts-limit' ),
                    self::get_setting( 'per-row' ),
                )
            ),

        );        
    }

    static function mosaic_images()
    {
        return array(

            'general' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'General', 'louvre' ),
                'options' => array(

                    array(
                        'name'  => esc_html__( 'Admin label', 'louvre' ),
                        'field' => 'input',
                        'type'  => 'text',
                        'id'    => 'admin-label',
                        'std'   => esc_html__( 'Mosaic images', 'louvre' )
                    ),

                    array(
                        'name'  => '',
                        'field' => 'input',
                        'type'  => 'hidden',
                        'id'    => 'element-icon',
                        'std'   => 'icon-coverflow',
                    ),

                    array(
                        'name'    => esc_html__( 'Choose style of images', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'rectangles' => esc_html__( 'Rectangles', 'louvre' ),
                            'square'     => esc_html__( 'Squares', 'louvre' ),
                            'style-3'    => esc_html__( 'Style 3', 'louvre' )
                        ),
                        'id'           => 'layout',
                        'std'          => 'rectangles',
                    ),            

                    array(
                        'name'    => esc_html__( 'Enable spacing between posts', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'       => 'gutter',
                        'std'      => 'y'
                    ),

                    array(
                        'name'    => esc_html__( 'How to display post content', 'louvre' ),
                        'desc'    => esc_html__( 'If you choose Display always, post title, categories and excerpt will be always visible. If you choose to display them on hover, they will only show up when user hovers the article.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'always' => esc_html__( 'Display always', 'louvre' ),
                            'hover'  => esc_html__( 'Display on hover', 'louvre' ),
                        ),
                        'id'           => 'hover-style',
                        'std'          => 'always',
                    ),                  


                    array(
                        'name'    => esc_html__( 'How to display titles', 'louvre' ),
                        'desc'    => esc_html__( 'Choose how to display titles. If you choose Titles with link option, the titles will be used as link. If you choose Convert titles to buttons, the titles will be displayed as buttons with URL.', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'title'   => esc_html__( 'Titles with link', 'louvre' ),
                            'button'  => esc_html__( 'Convert titles to buttons', 'louvre' ),
                        ),
                        'id'           => 'link-style',
                        'std'          => 'title',
                    ),                 

                    array(
                        'name'     => esc_html__( 'Add new item', 'louvre' ),
                        'field'    => 'tmpl',
                        'id'       => 'items',
                        'sortable' => 'true',
                        'std'      => array(),
                        'options'  => array(

                            array(
                                'name'       => esc_html__( 'Upload image', 'louvre' ),
                                'field'      => 'upload',
                                'media-type' => 'image',
                                'multiple'   => 'false',
                                'id'         => 'image',
                                'std'        => '',
                            ),

                            array(
                                'name'  => esc_html__( 'Add title', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'title',
                                'std'   => ''
                            ),

                            array(
                                'name'  => esc_html__( 'Redirect URL', 'louvre' ),
                                'field' => 'input',
                                'type'  => 'text',
                                'id'    => 'url',
                                'std'   => ''
                            ),

                            self::get_setting( 'target' ),
                        )
                    ),


                ),
            ),
        );
    }

    static function general( $settings, $type, $show = true )
    {

        if ( $type == 'import' ) return $settings;

        $settings['general']['options'] = array_merge( $settings['general']['options'], array(

                array(
                    'name'  => '',
                    'field' => 'input',
                    'type'  => 'hidden',
                    'id'    => 'element-type',
                    'std'   => $type
                )
            )
        );

        $settings['general']['options'] = array_merge( $settings['general']['options'], array(

            array(
                'name'  => esc_html__( 'Custom classes', 'louvre' ),
                'field' => 'input',
                'type'  => 'text',
                'id'    => 'custom-classes',
                'std'   => ''
            )

        ) );

        $settings = array_merge( $settings, array(

            'responsive' => array(
                'field'   => 'tab',
                'title'   => esc_html__( 'Responsiveness', 'louvre' ),
                'options' => array(

                    array(
                        'name'    => esc_html__( 'Show on large devices', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'  => 'lg',
                        'std' => 'y'
                    ),

                    array(
                        'name'    => esc_html__( 'Show on tablet landscape', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'  => 'md',
                        'std' => 'y'
                    ),

                    array(
                        'name'    => esc_html__( 'Show on tablet portrait', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'  => 'sm',
                        'std' => 'y'
                    ),

                    array(
                        'name'    => esc_html__( 'Show on mobile', 'louvre' ),
                        'field'   => 'select',
                        'options' => array(
                            'y' => esc_html__( 'Yes', 'louvre' ),
                            'n' => esc_html__( 'No', 'louvre' )
                        ),
                        'id'  => 'xs',
                        'std' => 'y'
                    ),
                )
            )
        ) );

        if ( ! $show ) {

            $settings['general']['options'] = array_merge( array(

                array(
                    'name'  => 'Allow adderess input to pass validation in temlate class',
                    'field' => 'input',
                    'type'  => 'text',
                    'id'    => 'address',
                    'std'   => ''
                )

            ), $settings['general']['options'] );
        }

        return $settings;
    }

    static function modal_fields( $type )
    {

        if ( empty( $type ) ) {

            echo esc_html__( 'Element type is empty.', 'louvre' );

            return;
        }

        $blocks = call_user_func( array( __CLASS__, str_replace( '-', '_', $type ) ) );

        $blocks = self::general( $blocks, $type );

        $li = '';
        $content = '';

        echo
            '<div class="airkit_element-settings">';

                foreach ( $blocks as $block ) {

                    $li .= '<li>' . $block['title'] . '</li>';

                    ob_start(); ob_clean();

                        echo '<div class="airkit_tab-content">';

                            foreach ( $block['options'] as $field ) {

                                if ( ! isset( $field['field'] ) ) continue;

                                if ( method_exists( __CLASS__, $field['field'] ) ) {

                                    call_user_func( array( __CLASS__, $field['field'] ) );

                                } else {

                                    call_user_func( array( 'airkit_Fields', $field['field'] ), $field, array() );
                                }
                            }

                        echo '</div>';

                    $content .= ob_get_clean();
                }

                echo '
                <ul class="airkit_tabs">' . $li . '</ul>
                <div class="airkit_tabs-content">' . $content . '</div>
            </div>';
    }

    static function render_map()
    {   ?>
        <style type="text/css">
            html, body, #map-canvas {
                width: 100%;
                height: 360px;
                margin: 0px;
                padding: 0px
            }
            #panel {
                z-index: 5;
                background-color: #fff;
                padding: 5px;
            }
        </style>
        <div id="panel" style="width:100%;">
            <input id="address" type="text" placeholder="<?php esc_html_e( 'Enter your address', 'louvre' ); ?>" name="address">
            <input class="ts-secondary-button airkit_find-address" type="button" value="<?php esc_html_e( 'Find address', 'louvre' ) ?>" onclick="codeAddress()">
        </div>

        <div id="map-canvas"></div>
        <?php
    }
}

// End.